@@ -12,7 +12,7 @@
 
 (define channel-envelope
   (dilambda
-   (let ((documentation "(channel-envelope snd chn) returns the current enved envelope associated with snd's channel chn"))
+   (let ((+documentation+ "(channel-envelope snd chn) returns the current enved envelope associated with snd's channel chn"))
      (lambda (snd chn)
        (or (channel-property 'enved-envelope snd chn)
 	   ())))
@@ -35,7 +35,7 @@
 
 (define mouse-down 0)
 (define mouse-up 0)
-(define click-time 10) ; .1 sec?
+(define click-time (/ internal-time-units-per-second 10.0)) ; sets whether a mouse motion is a click or a drag
 (define mouse-pos 0)
 (define mouse-new #f)
 
@@ -104,15 +104,12 @@
 				  (- (list-ref cur-env (+ mouse-pos 2)) .001))))))
 	    (ly (max 0.0 (min y 1.0))))
 	(set! (channel-envelope snd chn) 
-	      (let ((pos mouse-pos) 
-		    (x lx) 
-		    (y ly))
-		(do ((new-env ())
-		     (e cur-env (cddr e))
-		     (npos 0 (+ npos 2)))
-		    ((= npos pos) 
-		     (append new-env (list x y) (cddr e)))
-		  (set! new-env (append new-env (list (car e) (cadr e)))))))
+	      (do ((new-env ())
+		   (e cur-env (cddr e))
+		   (npos 0 (+ npos 2)))
+		  ((= npos mouse-pos) 
+		   (append new-env (list lx ly) (cddr e)))
+		(set! new-env (append new-env (list (car e) (cadr e))))))
 	(update-lisp-graph snd chn)))))
 
 
@@ -128,13 +125,12 @@
 			 (= mouse-pos 0)
 			 (>= mouse-pos (- (length cur-env) 2))))
 		(set! (channel-envelope snd chn)
-		      (let ((pos mouse-pos)
-			    (new-env ()))
+		      (let ((new-env ()))
 			(let search-point ((e cur-env)
 					   (npos 0))
 			  (if (null? e)
 			      new-env
-			      (if (= pos npos)
+			      (if (= mouse-pos npos)
 				  (append new-env (cddr e))
 				  (begin
 				    (set! new-env (append new-env (list (car e) (cadr e))))
@@ -164,7 +160,7 @@
 	      (set! (hook 'result) #t))))))
 
 (define start-enveloping
-  (let ((documentation "(start-enveloping) starts the enved processes, displaying an envelope editor in each channel"))
+  (let ((+documentation+ "(start-enveloping) starts the enved processes, displaying an envelope editor in each channel"))
     (lambda ()
       (hook-push after-open-hook create-initial-envelopes)
       (hook-push mouse-press-hook mouse-press-envelope)
@@ -173,7 +169,7 @@
       (hook-push key-press-hook enveloping-key-press))))
 
 (define stop-enveloping
-  (let ((documentation "(stop-enveloping) turns off the enved channel-specific envelope editors"))
+  (let ((+documentation+ "(stop-enveloping) turns off the enved channel-specific envelope editors"))
     (lambda ()
       (hook-remove after-open-hook create-initial-envelopes)
       (hook-remove mouse-press-hook mouse-press-envelope)
@@ -187,7 +183,7 @@
 ;;; some examples of using this envelope editor
 
 (define play-with-envs
-  (let ((documentation "(play-with-envs snd) sets channel amps during playback from the associated enved envelopes"))
+  (let ((+documentation+ "(play-with-envs snd) sets channel amps during playback from the associated enved envelopes"))
     (lambda* (sound)
       (do ((chans (channels sound))
 	   (chan 0 (+ 1 chan)))
@@ -203,7 +199,7 @@
 
 #|
 (define play-panned 
-  (let ((documentation "(play-panned snd) pans a mono sound following its enved envelope into a stereo sound"))
+  (let ((+documentation+ "(play-panned snd) pans a mono sound following its enved envelope into a stereo sound"))
     (lambda (sound)
       (let* ((bufsize 256)
 	     (data (make-float-vector (list 2 bufsize) 0.0))
