@@ -14,10 +14,10 @@
   (let ((st (seconds->samples (or beg 0.0)))
 	(dur (or outdur
 		 (/ (- (mus-sound-duration in-file) (or inbeg 0.0))
-		    (or (and srate (number? srate) (abs srate)) 1.0))))
+		    (or (and (real? srate) (abs srate)) 1.0))))
 	(in-chans (channels in-file))
 	(out-chans (channels *output*))
-	(reversed (or (and (number? srate) (negative? srate))
+	(reversed (or (and (real? srate) (negative? srate))
 		      (and (pair? srate) (pair? (cdr srate)) (negative? (cadr srate)))))
 	
 	(inloc (floor (* (or inbeg 0.0) (mus-sound-srate in-file)))))
@@ -25,14 +25,14 @@
     (let ((samps (seconds->samples dur))
 	  (mx (let ((ochans (max in-chans out-chans)))
 		(if matrix
-		    (make-float-vector (list ochans ochans) 0.0)
-		    (let ((v (make-float-vector (list ochans ochans) 0.0)))
+		    (make-float-vector (list ochans ochans))
+		    (let ((v (make-float-vector (list ochans ochans))))
 		      (do ((i 0 (+ i 1)))
 			  ((= i ochans))
 			(set! (v i i) 1.0))
 		      v))))
-	  (rev-mx (and *reverb* reverb-amount (> reverb-amount 0.0)
-		       (let ((rmx (make-float-vector (list in-chans in-chans) 0.0)))
+	  (rev-mx (and *reverb* (real? reverb-amount) (> reverb-amount 0.0)
+		       (let ((rmx (make-float-vector (list in-chans in-chans))))
 			 (do ((i 0 (+ i 1)))
 			     ((= i in-chans))
 			   (set! (rmx i 0) reverb-amount)) ; 0->assume 1 chan reverb stream, I think
@@ -95,7 +95,7 @@
 	  (let ((srcs (make-vector in-chans #f)))
 	    (do ((inp 0 (+ inp 1)))
 		((= inp in-chans))
-	      (vector-set! srcs inp (make-src :input (vector-ref file inp) :srate (if (number? srate) (abs srate) 0.0))))
+	      (vector-set! srcs inp (make-src :input (vector-ref file inp) :srate (if (real? srate) (abs srate) 0.0))))
 	    (mus-file-mix-with-envs file st samps mx rev-mx envs srcs srcenv *output* *reverb*)
 	    )))))
 
