@@ -17,16 +17,19 @@
 
 
 (define (mock->string obj . args)
-  (dynamic-wind
-      (lambda () (coverlet obj))
-      (lambda () (apply #_object->string (obj 'value) args))
-      (lambda () (openlet obj))))
+  (if (openlet? obj)
+      (dynamic-wind
+	  (lambda () (coverlet obj))
+	  (lambda () (apply #_object->string (obj 'value) args))
+	  (lambda () (openlet obj)))
+      (apply #_object->string (obj 'value) args)))
 
 
 (define (make-local-method f)
   (make-method f (lambda (obj) (obj 'value))))
 
 
+
 ;;; --------------------------------------------------------------------------------
 
 (define *mock-vector*
@@ -40,14 +43,14 @@
 					    (#_vector-set! (obj 'value) i val)
 					    (error 'wrong-type-arg "vector-set! ~S ~S ~S" obj i val))) ; the wrong arg here is 'i
 		  'vector-set!        (lambda (obj i val) ((obj 'local-set!) obj i val) val)
-		  'let-set!           (lambda (obj i val) ((obj 'local-set!) obj i val) val)
+		  'let-set-fallback  (lambda (obj i val) ((obj 'local-set!) obj i val) val)
 		  
 		  'vector-ref         (lambda (obj i) 
 					(if (mock-vector? obj)
 					    (#_vector-ref (obj 'value) i)
 					    (error 'wrong-type-arg "vector-ref ~S ~S" obj i)))
 		  
-		  'let-ref            (lambda (obj i) (#_vector-ref (obj 'value) i))   ; the implicit case, so 'i can't be the culprit
+		  'let-ref-fallback   (lambda (obj i) (#_vector-ref (obj 'value) i))   ; the implicit case, so 'i can't be the culprit
 		  'vector-length      (lambda (obj) (#_length (obj 'value)))
 		  'vector-append      (make-local-method #_vector-append)
 		  'reverse            (lambda (obj) (#_reverse (obj 'value)))
@@ -146,9 +149,9 @@
        'object->string mock->string
        'initial-element #f
        'vector-ref local-ref
-       'let-ref local-ref
+       'let-ref-fallback local-ref
        'vector-set! local-set!
-       'let-set! local-set!))))
+       'let-set-fallback local-set!))))
 |#
 
 
@@ -167,7 +170,7 @@
 		  'let-ref-fallback   (lambda (obj key)
 					(if (defined? 'mock-hash-table-table obj)
 					    (#_hash-table-ref (obj 'mock-hash-table-table) key)))
-		  'let-set!-fallback  (lambda (obj key val)  
+		  'let-set-fallback  (lambda (obj key val)  
 					(if (defined? 'mock-hash-table-table obj)
 					    (#_hash-table-set! (obj 'mock-hash-table-table) key val)))
 		  
@@ -186,7 +189,7 @@
 		  'copy               (lambda* (source dest . args)
 					(if (mock-hash-table? source)
 					    (if (and dest (not (let? dest)))
-						(apply copy (obj 'mock-hash-table-table) dest args)
+						(apply copy (source 'mock-hash-table-table) dest args)
 						(let ((nobj (or dest (openlet (copy (coverlet source))))))
 						  (openlet source)
 						  (set! (nobj 'mock-hash-table-table) (copy (source 'mock-hash-table-table)))
@@ -267,8 +270,8 @@
 		  'object->string         (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-string*" "#<mock-string-class>")))
 		  'arity                  (lambda (obj) (#_arity (obj 'value)))
 		  'make-iterator          (lambda (obj) (#_make-iterator (obj 'value)))
-		  'let-ref                (lambda (obj i) (#_string-ref (obj 'value) i))           ; these are the implicit cases
-		  'let-set!               (lambda (obj i val) (string-set! (obj 'value) i val))
+		  'let-ref-fallback       (lambda (obj i) (#_string-ref (obj 'value) i))           ; these are the implicit cases
+		  'let-set-fallback      (lambda (obj i val) (string-set! (obj 'value) i val))
 		  'string-length          (lambda (obj) (#_length (obj 'value)))
 		  'string-append          (make-local-method #_string-append)
 		  'string-copy            (lambda (obj) (#_copy (obj 'value)))
@@ -895,8 +898,8 @@
 		  'memq             (lambda (val obj) (#_memq val (obj 'value)))
 		  'memv             (lambda (val obj) (#_memv val (obj 'value)))
 		  'member           (lambda (val obj . args) (apply #_member val (obj 'value) args))
-		  'let-ref          (lambda (obj ind) (coverlet obj) (let ((val (#_list-ref (obj 'value) ind))) (openlet obj) val))
-		  'let-set!         (lambda (obj ind val) (coverlet obj) (#_list-set! (obj 'value) ind val) (openlet obj) val)
+		  'let-ref-fallback (lambda (obj ind) (coverlet obj) (let ((val (#_list-ref (obj 'value) ind))) (openlet obj) val))
+		  'let-set-fallback (lambda (obj ind val) (coverlet obj) (#_list-set! (obj 'value) ind val) (openlet obj) val)
 		  'arity            (lambda (obj) (#_arity (obj 'value)))
 		  'fill!            (lambda (obj val) (#_fill! (obj 'value) val))
 		  'reverse          (lambda (obj) (#_reverse (obj 'value)))
@@ -961,7 +964,7 @@
        (sublet (*mock-pair* 'mock-pair-class)
 	 'object->string   mock->string
 	 
-	 'let-set!         (lambda (obj i val) 
+	 'let-set-fallback (lambda (obj i val) 
 			     (set! (obj 'value) (append (copy (obj 'value) (make-list (+ i 1))) (list-tail (obj 'value) (+ i 1))))
 			     (list-set! (obj 'value) i val))
 	 'list-set!        (lambda (obj i val) 
@@ -1000,7 +1003,7 @@
 		 'symbol->string        (lambda (obj) (#_symbol->string (obj 'value)))
 		 'symbol->value         (lambda (obj . args) (apply #_symbol->value (obj 'value) args))
 		 'symbol->dynamic-value (lambda (obj) (#_symbol->dynamic-value (obj 'value)))
-		 'symbol-access         (lambda (obj . args) (apply #_symbol-access (obj 'value) args))
+		 'symbol-setter         (lambda (obj . args) (apply #_symbol-setter (obj 'value) args))
 		 'provided?             (lambda (obj) (#_provided? (obj 'value)))
 		 'provide               (lambda (obj) (#_provide (obj 'value)))
 		 'defined?              (lambda (obj) (#_defined? (obj 'value)))
