@@ -131,7 +131,7 @@
 (define write-simple write)
 
 (define (eof-object) #<eof>)
-(define (features) *features*)
+(define-macro (features) '*features*) ; needs to be the local *features*
 
 
 (define (with-exception-handler handler thunk) (catch #t thunk handler))
@@ -421,7 +421,6 @@
 
 ;; other minor differences: 
 ;;  in s7, single-quote can occur in a name
-;;  s7 doesn't currently implement #\xxxx characters
 
 
 ;; records
