@@ -369,7 +369,7 @@ typedef struct snd_info {
   int selected_channel;
   char *filename;
   char *short_filename;
-  int nchans;
+  unsigned int nchans;  /* "unsigned" to make gcc 7.1 happy */
   Xen properties;
   int properties_loc;
   bool remembering;
@@ -1717,6 +1717,7 @@ void reset_mix_ctr(void);
 void preload_mixes(mix_state **mixes, int low_id, ed_list *ed);
 void free_channel_mixes(chan_info *cp);
 void delete_any_remaining_mix_temp_files_at_exit(chan_info *cp);
+void mix_info_to_file(FILE *fd, chan_info *cp);
 int mix_sync_from_id(int id);
 int mix_set_sync_from_id(int id, int new_sync);
 void set_mix_waveform_height(int new_val);
