@@ -1286,7 +1286,9 @@ env *xen_to_env(Xen res)
 		    {
 		      Xen el;
 		      el = Xen_car(lst);
-		      if ((!(Xen_is_number(Xen_car(el)))) ||
+		      if ((!Xen_is_pair(el)) ||
+			  (!(Xen_is_number(Xen_car(el)))) ||
+			  (!(Xen_is_pair(Xen_cdr(el)))) ||
 			  (!(Xen_is_number(Xen_cadr(el)))))
 			{
 			  free(data);
@@ -1930,12 +1932,12 @@ stretch-envelope from env.fth: \n\
   ss->enved->clipping = DEFAULT_ENVED_CLIPPING;
 
 #if HAVE_SCHEME
-  s7_symbol_set_access(s7, ss->enved_base_symbol, s7_make_function(s7, "[acc-" S_enved_base "]", acc_enved_base, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->enved_filter_order_symbol, s7_make_function(s7, "[acc-" S_enved_filter_order "]", acc_enved_filter_order, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->enved_power_symbol, s7_make_function(s7, "[acc-" S_enved_power "]", acc_enved_power, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->enved_style_symbol, s7_make_function(s7, "[acc-" S_enved_style "]", acc_enved_style, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->enved_target_symbol, s7_make_function(s7, "[acc-" S_enved_target "]", acc_enved_target, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->enved_with_wave_symbol, s7_make_function(s7, "[acc-" S_enved_with_wave "]", acc_enved_with_wave, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_base_symbol, s7_make_function(s7, "[acc-" S_enved_base "]", acc_enved_base, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_filter_order_symbol, s7_make_function(s7, "[acc-" S_enved_filter_order "]", acc_enved_filter_order, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_power_symbol, s7_make_function(s7, "[acc-" S_enved_power "]", acc_enved_power, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_style_symbol, s7_make_function(s7, "[acc-" S_enved_style "]", acc_enved_style, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_target_symbol, s7_make_function(s7, "[acc-" S_enved_target "]", acc_enved_target, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->enved_with_wave_symbol, s7_make_function(s7, "[acc-" S_enved_with_wave "]", acc_enved_with_wave, 2, 0, false, "accessor"));
 
   s7_symbol_set_documentation(s7, ss->enved_base_symbol, "*enved-base*: envelope editor exponential base value (1.0)");
   s7_symbol_set_documentation(s7, ss->enved_filter_order_symbol, "*enved-filter-order*: envelope editor's FIR filter order (40)");
