@@ -886,7 +886,7 @@ GtkWidget *make_transform_dialog(bool managed)
       SG_SIGNAL_CONNECT(transform_dialog, "delete_event", delete_transform_dialog, NULL);
       gtk_window_set_title(GTK_WINDOW(transform_dialog), "Transform Options");
       sg_make_resizable(transform_dialog);
-      gtk_container_set_border_width(GTK_CONTAINER(transform_dialog), 6);
+      sg_container_set_border_width(GTK_CONTAINER(transform_dialog), 6);
       gtk_widget_realize(transform_dialog);
       /* gtk_window_resize(GTK_WINDOW(transform_dialog), 400, 500); */
 
@@ -951,11 +951,11 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_widget_show(vbb);
 
 	label = snd_gtk_highlight_label_new("display");
-	gtk_box_pack_start(GTK_BOX(vbb), label, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vbb), label, false, false, 0);
 	gtk_widget_show(label);
 
 	hb = gtk_hbox_new(false, 15);
-	gtk_box_pack_start(GTK_BOX(vbb), hb, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vbb), hb, false, false, 0);
 	gtk_widget_show(hb);
 
 	buttons = gtk_vbox_new(false, 0);
@@ -964,63 +964,63 @@ GtkWidget *make_transform_dialog(bool managed)
 	normal_fft_button = gtk_radio_button_new_with_label(NULL, "single transform");
 	widget_set_margin_left(normal_fft_button, LEFT_MARGIN);
 	add_check_button_style(normal_fft_button);
-	gtk_box_pack_start(GTK_BOX(buttons), normal_fft_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), normal_fft_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(normal_fft_button);
 	SG_SIGNAL_CONNECT(normal_fft_button, "clicked", normal_fft_callback, NULL);
 	
 	sono_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), "sonogram");
 	widget_set_margin_left(sono_button, LEFT_MARGIN);
 	add_check_button_style(sono_button);
-	gtk_box_pack_start(GTK_BOX(buttons), sono_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), sono_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(sono_button);
 	SG_SIGNAL_CONNECT(sono_button, "clicked", sonogram_callback, NULL);
 	
 	spectro_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(normal_fft_button)), "spectrogram");
 	widget_set_margin_left(spectro_button, LEFT_MARGIN);
 	add_check_button_style(spectro_button);
-	gtk_box_pack_start(GTK_BOX(buttons), spectro_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), spectro_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(spectro_button);
 	SG_SIGNAL_CONNECT(spectro_button, "clicked", spectrogram_callback, NULL);
 	
 	peaks_button = gtk_check_button_new_with_label("peaks");
 	widget_set_margin_left(peaks_button, LEFT_MARGIN);
 	add_check_button_style(peaks_button);
-	gtk_box_pack_start(GTK_BOX(buttons), peaks_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), peaks_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(peaks_button);
 	SG_SIGNAL_CONNECT(peaks_button, "toggled", peaks_callback, NULL);
 	
 	db_button = gtk_check_button_new_with_label("dB");
 	widget_set_margin_left(db_button, LEFT_MARGIN);
 	add_check_button_style(db_button);
-	gtk_box_pack_start(GTK_BOX(buttons), db_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), db_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(db_button);
 	SG_SIGNAL_CONNECT(db_button, "toggled", db_callback, NULL);
 	
 	logfreq_button = gtk_check_button_new_with_label("log freq");
 	widget_set_margin_left(logfreq_button, LEFT_MARGIN);
 	add_check_button_style(logfreq_button);
-	gtk_box_pack_start(GTK_BOX(buttons), logfreq_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), logfreq_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(logfreq_button);
 	SG_SIGNAL_CONNECT(logfreq_button, "toggled", logfreq_callback, NULL);
 	
 	normalize_button = gtk_check_button_new_with_label("normalize");
 	widget_set_margin_left(normalize_button, LEFT_MARGIN);
 	add_check_button_style(normalize_button);
-	gtk_box_pack_start(GTK_BOX(buttons), normalize_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), normalize_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(normalize_button);
 	SG_SIGNAL_CONNECT(normalize_button, "toggled", normalize_callback, NULL);
 	
 	selection_button = gtk_check_button_new_with_label("selection");
 	widget_set_margin_left(selection_button, LEFT_MARGIN);
 	add_check_button_style(selection_button);
-	gtk_box_pack_start(GTK_BOX(buttons), selection_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_start(GTK_BOX(buttons), selection_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(selection_button);
 	SG_SIGNAL_CONNECT(selection_button, "toggled", selection_callback, NULL);
 
 	phases_button = gtk_check_button_new_with_label("with phases");
 	widget_set_margin_left(phases_button, LEFT_MARGIN);
 	add_check_button_style(phases_button);
-	gtk_box_pack_end(GTK_BOX(buttons), phases_button, false, false, DISPLAY_MARGIN);
+	sg_box_pack_end(GTK_BOX(buttons), phases_button, false, false, DISPLAY_MARGIN);
 	gtk_widget_show(phases_button);
 	SG_SIGNAL_CONNECT(phases_button, "toggled", phases_callback, NULL);
 	
@@ -1029,12 +1029,12 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_container_add(GTK_CONTAINER(hb), vb);
 	
 	pk_lab = snd_gtk_highlight_label_new("max peaks");
-	gtk_box_pack_start(GTK_BOX(vb), pk_lab, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), pk_lab, false, false, 0);
 	gtk_widget_show(pk_lab);
 	
 	pk_vals = (GtkAdjustment *)gtk_adjustment_new(max_transform_peaks(ss), 2, 1000, 2, 10, 0);
 	peaks_txt = gtk_spin_button_new(GTK_ADJUSTMENT(pk_vals), 0.0, 0);
-	gtk_box_pack_start(GTK_BOX(vb), peaks_txt, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), peaks_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(peaks_txt), true);
 	SG_SIGNAL_CONNECT(pk_vals, "value_changed", max_peaks_callback, (gpointer)peaks_txt);
 	SG_SIGNAL_CONNECT(peaks_txt, "enter_notify_event", spin_button_focus_callback, NULL);
@@ -1042,16 +1042,16 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_widget_show(peaks_txt);
 
 	sep1 = gtk_vseparator_new();
-	gtk_box_pack_start(GTK_BOX(vb), sep1, false, false, RIGHT_SEP_SIZE);
+	sg_box_pack_start(GTK_BOX(vb), sep1, false, false, RIGHT_SEP_SIZE);
 	gtk_widget_show(sep1);
 
 	db_lab = snd_gtk_highlight_label_new("min dB");
-	gtk_box_pack_start(GTK_BOX(vb), db_lab, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), db_lab, false, false, 0);
 	gtk_widget_show(db_lab);
       
 	db_vals = (GtkAdjustment *)gtk_adjustment_new((int)(-(min_dB(ss))), 2, 1000, 2, 10, 0); /* can't be negative!! */
 	db_txt = gtk_spin_button_new(GTK_ADJUSTMENT(db_vals), 0.0, 0);
-	gtk_box_pack_start(GTK_BOX(vb), db_txt, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), db_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(db_txt), true);
 	SG_SIGNAL_CONNECT(db_vals, "value_changed", min_db_callback, (gpointer)db_txt);
 	SG_SIGNAL_CONNECT(db_txt, "enter_notify_event", spin_button_focus_callback, NULL);
@@ -1059,16 +1059,16 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_widget_show(db_txt);
 
 	sep2 = gtk_vseparator_new();
-	gtk_box_pack_start(GTK_BOX(vb), sep2, false, false, RIGHT_SEP_SIZE);
+	sg_box_pack_start(GTK_BOX(vb), sep2, false, false, RIGHT_SEP_SIZE);
 	gtk_widget_show(sep2);
 
 	lf_lab = snd_gtk_highlight_label_new("log freq start");
-	gtk_box_pack_start(GTK_BOX(vb), lf_lab, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), lf_lab, false, false, 0);
 	gtk_widget_show(lf_lab);
       
 	lf_vals = (GtkAdjustment *)gtk_adjustment_new((int)(log_freq_start(ss)), 1, 1000, 1, 10, 0);
 	lf_txt = gtk_spin_button_new(GTK_ADJUSTMENT(lf_vals), 0.0, 0);
-	gtk_box_pack_start(GTK_BOX(vb), lf_txt, false, false, 0);
+	sg_box_pack_start(GTK_BOX(vb), lf_txt, false, false, 0);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(lf_txt), true);
 	SG_SIGNAL_CONNECT(lf_vals, "value_changed", log_freq_callback, (gpointer)lf_txt);
 	SG_SIGNAL_CONNECT(lf_txt, "enter_notify_event", spin_button_focus_callback, NULL);
@@ -1105,16 +1105,16 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_container_add(GTK_CONTAINER(ab_frame), ab_box);	
 	
 	ab_label = snd_gtk_highlight_label_new("window parameter");
-	gtk_box_pack_start(GTK_BOX(ab_box), ab_label, false, false, 1);
+	sg_box_pack_start(GTK_BOX(ab_box), ab_label, false, false, 1);
 	gtk_widget_show(ab_label);
 	
 	
 	alpha_box = gtk_hbox_new(false, 0);
-	gtk_box_pack_start(GTK_BOX(ab_box), alpha_box, false, false, 1);      
+	sg_box_pack_start(GTK_BOX(ab_box), alpha_box, false, false, 1);      
 	gtk_widget_show(alpha_box);
 	
 	alpha_label = gtk_label_new("alpha: ");
-	gtk_box_pack_start(GTK_BOX(alpha_box), alpha_label, false, false, 8);
+	sg_box_pack_start(GTK_BOX(alpha_box), alpha_label, false, false, 8);
 	gtk_widget_show(alpha_label);      
 	
 	alpha_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
@@ -1127,16 +1127,16 @@ GtkWidget *make_transform_dialog(bool managed)
 	SG_SIGNAL_CONNECT(alpha_adj, "value_changed", alpha_callback, NULL);
 	SG_SIGNAL_CONNECT(alpha_scale, "format-value", scale_double_format_callback, NULL);
 	
-	gtk_box_pack_start(GTK_BOX(alpha_box), alpha_scale, true, true, 1);      
+	sg_box_pack_start(GTK_BOX(alpha_box), alpha_scale, true, true, 1);      
 	
 	
 	beta_box = gtk_hbox_new(false, 0);
-	gtk_box_pack_start(GTK_BOX(ab_box), beta_box, false, false, 1);      
+	sg_box_pack_start(GTK_BOX(ab_box), beta_box, false, false, 1);      
 	gtk_widget_show(beta_box);
 	
 
 	beta_label = gtk_label_new("beta:  ");
-	gtk_box_pack_start(GTK_BOX(beta_box), beta_label, false, false, 8);
+	sg_box_pack_start(GTK_BOX(beta_box), beta_label, false, false, 8);
 	gtk_widget_show(beta_label);      
 	
 	beta_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
@@ -1149,7 +1149,7 @@ GtkWidget *make_transform_dialog(bool managed)
 	SG_SIGNAL_CONNECT(beta_adj, "value_changed", beta_callback, NULL);
 	SG_SIGNAL_CONNECT(beta_scale, "format-value", scale_double_format_callback, NULL);
 	
-	gtk_box_pack_start(GTK_BOX(beta_box), beta_scale, true, true, 1);      
+	sg_box_pack_start(GTK_BOX(beta_box), beta_scale, true, true, 1);      
 	
 	gtk_widget_show(alpha_scale);
 	gtk_widget_show(beta_scale);
@@ -1168,15 +1168,15 @@ GtkWidget *make_transform_dialog(bool managed)
       gtk_container_add(GTK_CONTAINER(se_frame), se_box);	
 
       se_label = snd_gtk_highlight_label_new("spectrum start/end");
-      gtk_box_pack_start(GTK_BOX(se_box), se_label, false, false, 1);
+      sg_box_pack_start(GTK_BOX(se_box), se_label, false, false, 1);
       gtk_widget_show(se_label);
 
       start_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(se_box), start_box, false, false, 1);      
+      sg_box_pack_start(GTK_BOX(se_box), start_box, false, false, 1);      
       gtk_widget_show(start_box);
 
       start_label = gtk_label_new("start: ");
-      gtk_box_pack_start(GTK_BOX(start_box), start_label, false, false, 8);
+      sg_box_pack_start(GTK_BOX(start_box), start_label, false, false, 8);
       gtk_widget_show(start_label);      
 
       spectrum_start_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
@@ -1189,15 +1189,15 @@ GtkWidget *make_transform_dialog(bool managed)
       SG_SIGNAL_CONNECT(spectrum_start_adj, "value_changed", spectrum_start_callback, NULL);
       SG_SIGNAL_CONNECT(spectrum_start_scale, "format-value", scale_double_format_callback, NULL);
 
-      gtk_box_pack_start(GTK_BOX(start_box), spectrum_start_scale, true, true, 1);      
+      sg_box_pack_start(GTK_BOX(start_box), spectrum_start_scale, true, true, 1);      
 
 
       end_box = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(se_box), end_box, false, false, 1);      
+      sg_box_pack_start(GTK_BOX(se_box), end_box, false, false, 1);      
       gtk_widget_show(end_box);
 
       end_label = gtk_label_new("end:  ");
-      gtk_box_pack_start(GTK_BOX(end_box), end_label, false, false, 8);
+      sg_box_pack_start(GTK_BOX(end_box), end_label, false, false, 8);
       gtk_widget_show(end_label);      
 
       spectrum_end_adj = (GtkAdjustment *)gtk_adjustment_new(0.0, 0.0, 1.01, 0.001, 0.01, .01);
@@ -1210,7 +1210,7 @@ GtkWidget *make_transform_dialog(bool managed)
       SG_SIGNAL_CONNECT(spectrum_end_adj, "value_changed", spectrum_end_callback, NULL);
       SG_SIGNAL_CONNECT(spectrum_end_scale, "format-value", scale_double_format_callback, NULL);
 
-      gtk_box_pack_start(GTK_BOX(end_box), spectrum_end_scale, true, true, 1);      
+      sg_box_pack_start(GTK_BOX(end_box), spectrum_end_scale, true, true, 1);      
 
       gtk_widget_show(spectrum_start_scale);
       gtk_widget_show(spectrum_end_scale);
@@ -1232,11 +1232,11 @@ GtkWidget *make_transform_dialog(bool managed)
 	gtk_container_add(GTK_CONTAINER(graph_frame), g_vbox);	
 
 	fft_window_label = snd_gtk_highlight_label_new(mus_fft_window_name(fft_window(ss)));
-	gtk_box_pack_start(GTK_BOX(g_vbox), fft_window_label, false, false, 1);
+	sg_box_pack_start(GTK_BOX(g_vbox), fft_window_label, false, false, 1);
 	gtk_widget_show(fft_window_label);
 
 	graph_drawer = gtk_drawing_area_new();
-	gtk_box_pack_end(GTK_BOX(g_vbox), graph_drawer, true, true, 0);
+	sg_box_pack_end(GTK_BOX(g_vbox), graph_drawer, true, true, 0);
 	widget_modify_bg(graph_drawer, GTK_STATE_NORMAL, ss->white);
 	gtk_widget_show(g_vbox);
 
