@@ -52,6 +52,7 @@ static gint window_close(GtkWidget *w, GdkEvent *event, gpointer context)
 }
 
 
+#if (!GTK_CHECK_VERSION(3, 92, 1))
 static GtkWidget **iconify_active_dialogs = NULL;
 
 static gint window_iconify(GtkWidget *w, GdkEventWindowState *event, gpointer context)
@@ -92,6 +93,7 @@ static gint window_iconify(GtkWidget *w, GdkEventWindowState *event, gpointer co
     }
   return(0);
 }
+#endif
 
 
 static guint auto_update_proc = 0;
@@ -306,8 +308,11 @@ static void startup_funcs(void)
 
   /* trap outer-level Close for cleanup check */
   SG_SIGNAL_CONNECT(main_shell(ss), "delete_event", window_close, NULL);
+
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   /* when iconified, we need to hide any dialogs as well */
   SG_SIGNAL_CONNECT(main_shell(ss), "window_state_event", window_iconify, NULL);
+#endif
 
   ss->graph_cursor = GDK_CURSOR_NEW((GdkCursorType)in_graph_cursor(ss));
   ss->wait_cursor = GDK_CURSOR_NEW(GDK_WATCH);
@@ -604,7 +609,7 @@ void snd_doit(int argc, char **argv)
 
       sound_pane(ss) = gtk_vpaned_new();
       add_paned_style(sound_pane(ss));
-      gtk_container_set_border_width(GTK_CONTAINER(sound_pane(ss)), 0);
+      sg_container_set_border_width(GTK_CONTAINER(sound_pane(ss)), 0);
       gtk_container_add(GTK_CONTAINER(main_pane(ss)), sound_pane(ss));
 
       if (sound_style(ss) == SOUNDS_IN_NOTEBOOK)
