@@ -85,7 +85,7 @@ static GtkWidget *make_basic_row(GtkWidget *box)
   GtkWidget *row, *r;
   r = gtk_event_box_new(); /* not button! */
   gtk_widget_set_hexpand(GTK_WIDGET(r), true);
-  gtk_box_pack_start(GTK_BOX(box), r, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), r, false, false, 0);
   add_highlight_button_style(r);
   gtk_widget_show(r);
   
@@ -96,7 +96,7 @@ static GtkWidget *make_basic_row(GtkWidget *box)
 #else
   GtkWidget *row;
   row = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(box), row, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), row, false, false, 0);
   gtk_widget_show(row);
 #endif
 
@@ -203,7 +203,7 @@ static GtkWidget *make_row_label(prefs_info *prf, const char *label, GtkWidget *
 #endif
 #endif
   gtk_size_group_add_widget(label_group, w);
-  gtk_box_pack_start(GTK_BOX(box), w, PACK_1, PACK_2, 0);
+  sg_box_pack_start(GTK_BOX(box), w, PACK_1, PACK_2, 0);
   gtk_widget_show(w);
   prf->saved_label = label;
 
@@ -217,7 +217,7 @@ static void make_row_inner_label(prefs_info *prf, const char *label, GtkWidget *
 {
   GtkWidget *w;
   w = gtk_label_new(label);
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, 4);
+  sg_box_pack_start(GTK_BOX(box), w, false, false, 4);
   gtk_widget_show(w);
 }
 
@@ -228,7 +228,7 @@ static void make_row_middle_separator(GtkWidget *box)
 {
   GtkWidget *w;
   w = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, 10);
+  sg_box_pack_start(GTK_BOX(box), w, false, false, 10);
   gtk_widget_show(w);
 }
 
@@ -239,7 +239,7 @@ static void make_row_inner_separator(int width, GtkWidget *box)
 {
   GtkWidget *w;
   w = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, width);
+  sg_box_pack_start(GTK_BOX(box), w, false, false, width);
   gtk_widget_show(w);
 }
 
@@ -253,7 +253,7 @@ static GtkWidget *make_row_toggle_with_label(prefs_info *prf, bool current_value
     w = gtk_check_button_new_with_label(label);
   else w = gtk_check_button_new();
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), current_value);
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, 0); /* was 10 */
+  sg_box_pack_start(GTK_BOX(box), w, false, false, 0); /* was 10 */
   gtk_widget_show(w);
 
   SG_SIGNAL_CONNECT(w, "toggled", prefs_change_callback, NULL);
@@ -274,7 +274,7 @@ static GtkWidget *make_row_error(prefs_info *prf, GtkWidget *box)
   GtkWidget *w;
 
   w = gtk_label_new("");
-  gtk_box_pack_end(GTK_BOX(box), w, true, false, 0);
+  sg_box_pack_end(GTK_BOX(box), w, true, false, 0);
   gtk_widget_show(w);
   return(w);
 }
@@ -375,7 +375,7 @@ static GtkWidget *make_row_arrows(prefs_info *prf, GtkWidget *box)
 #endif
 
   ev_down = gtk_event_box_new();
-  gtk_box_pack_start(GTK_BOX(box), ev_down, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), ev_down, false, false, 0);
   gtk_widget_show(ev_down);
 
 #if GTK_CHECK_VERSION(3, 14, 0)
@@ -387,7 +387,7 @@ static GtkWidget *make_row_arrows(prefs_info *prf, GtkWidget *box)
   gtk_widget_show(down);
 
   ev_up = gtk_event_box_new();
-  gtk_box_pack_start(GTK_BOX(box), ev_up, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), ev_up, false, false, 0);
   gtk_widget_show(ev_up);
 
 #if GTK_CHECK_VERSION(3, 14, 0)
@@ -438,7 +438,7 @@ static prefs_info *prefs_row_with_toggle(const char *label, const char *varname,
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -480,7 +480,7 @@ static prefs_info *prefs_row_with_two_toggles(const char *label, const char *var
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -575,7 +575,7 @@ static GtkWidget *make_row_text(prefs_info *prf, const char *text_value, int col
   gtk_editable_set_editable(GTK_EDITABLE(w), true);
   settings = gtk_widget_get_settings(w);
   g_object_set(settings, "gtk-entry-select-on-focus", false, NULL);
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), w, false, false, 0);
   gtk_widget_show(w);
 
   info = (text_info *)calloc(1, sizeof(text_info));
@@ -609,7 +609,7 @@ static prefs_info *prefs_row_with_toggle_with_text(const char *label, const char
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -644,7 +644,7 @@ static prefs_info *prefs_row_with_toggle_with_two_texts(const char *label, const
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -685,7 +685,7 @@ static prefs_info *prefs_row_with_text_with_toggle(const char *label, const char
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -723,7 +723,7 @@ static prefs_info *prefs_row_with_text_and_three_toggles(const char *label, cons
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -765,7 +765,7 @@ static GtkWidget *make_row_radio_box(prefs_info *prf,
   int i;
 
   w = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(box), w, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), w, false, false, 0);
   gtk_widget_show(w);
 
   prf->radio_buttons = (GtkWidget **)calloc(num_labels, sizeof(GtkWidget *));
@@ -777,7 +777,7 @@ static GtkWidget *make_row_radio_box(prefs_info *prf,
 	current_button = gtk_radio_button_new_with_label(NULL, labels[i]);
       else current_button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(prf->radio_buttons[0])), labels[i]);
       prf->radio_buttons[i] = current_button;
-      gtk_box_pack_start(GTK_BOX(w), current_button, false, false, 0);
+      sg_box_pack_start(GTK_BOX(w), current_button, false, false, 0);
       set_user_int_data(G_OBJECT(current_button), i);
       gtk_widget_show(current_button);
       SG_SIGNAL_CONNECT(current_button, "clicked", call_radio_func, (gpointer)prf);
@@ -808,7 +808,7 @@ static prefs_info *prefs_row_with_radio_box(const char *label, const char *varna
 
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -841,7 +841,7 @@ static prefs_info *prefs_row_with_radio_box_and_number(const char *label, const
 
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -900,7 +900,7 @@ static prefs_info *prefs_row_with_scale(const char *label, const char *varname,
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -912,7 +912,7 @@ static prefs_info *prefs_row_with_scale(const char *label, const char *varname,
 
   prf->adj = (GtkAdjustment *)gtk_adjustment_new(current_value /max_val, 0.0, 1.01, 0.001, 0.01, .01);
   prf->scale = gtk_hscale_new(GTK_ADJUSTMENT(prf->adj));
-  gtk_box_pack_start(GTK_BOX(hb), prf->scale, true, true, 4);
+  sg_box_pack_start(GTK_BOX(hb), prf->scale, true, true, 4);
   gtk_widget_show(prf->scale);
   gtk_range_set_update_policy(GTK_RANGE(GTK_SCALE(prf->scale)), GTK_UPDATE_CONTINUOUS);
   gtk_scale_set_draw_value(GTK_SCALE(prf->scale), false);
@@ -945,7 +945,7 @@ static prefs_info *prefs_row_with_text(const char *label, const char *varname, c
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -975,7 +975,7 @@ static prefs_info *prefs_row_with_two_texts(const char *label, const char *varna
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -1012,7 +1012,7 @@ static prefs_info *prefs_row_with_number(const char *label, const char *varname,
 
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);
@@ -1050,7 +1050,7 @@ static prefs_info *prefs_row_with_list(const char *label, const char *varname, c
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);  
@@ -1065,7 +1065,7 @@ static prefs_info *prefs_row_with_list(const char *label, const char *varname, c
     gtk_combo_box_append_text(GTK_COMBO_BOX(prf->text), (values[i]) ? values[i] : " ");
 #endif
   sg_entry_set_text(GTK_ENTRY(BIN_CHILD(prf->text)), value);
-  gtk_box_pack_start(GTK_BOX(hb), prf->text, false, false, 4);
+  sg_box_pack_start(GTK_BOX(hb), prf->text, false, false, 4);
   gtk_widget_show(prf->text);
 
   prf->error = make_row_error(prf, hb);
@@ -1091,6 +1091,9 @@ static void pixel_to_rgb(color_t pix, double *r, double *g, double *b)
 #if GTK_CHECK_VERSION(3, 0, 0)
 static void display_color(GtkWidget *w, color_t pixel)
 {
+#if GTK_CHECK_VERSION(3, 92, 1)
+  return;
+#else
   cairo_t *cr;
 #if GTK_CHECK_VERSION(3, 22, 0)
   GdkWindow *window;
@@ -1109,6 +1112,7 @@ static void display_color(GtkWidget *w, color_t pixel)
 #else
   cairo_destroy(cr);
 #endif
+#endif
 }
 #endif
 
@@ -1280,7 +1284,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   prf->label = make_row_label(prf, label, row);
   hb = gtk_hbox_new(false, 0);
   gtk_size_group_add_widget(widgets_group, hb);
-  gtk_box_pack_start(GTK_BOX(row), hb, false, false, 0);
+  sg_box_pack_start(GTK_BOX(row), hb, false, false, 0);
   gtk_widget_show(hb);
 
   make_row_middle_separator(hb);    
@@ -1290,7 +1294,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
     frame = gtk_frame_new(NULL);
     gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
     prf->color_texts = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-    gtk_box_pack_start(GTK_BOX(hb), frame, false, false, 4);
+    sg_box_pack_start(GTK_BOX(hb), frame, false, false, 4);
     gtk_size_group_add_widget(prf->color_texts, frame);
 
     prf->color = gtk_drawing_area_new();
@@ -1324,7 +1328,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   /* second row */
 
   row2 = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(box), row2, false, false, 0);
+  sg_box_pack_start(GTK_BOX(box), row2, false, false, 0);
   gtk_widget_show(row2);
 
   make_row_inner_separator(20, row2);
@@ -1332,7 +1336,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   prf->radj = (GtkAdjustment *)gtk_adjustment_new(r, 0.0, 1.01, 0.001, 0.01, .01);
   prf->rscl = gtk_hscale_new(GTK_ADJUSTMENT(prf->radj));
   gtk_widget_set_name(prf->rscl, "prefs_color_scale");
-  gtk_box_pack_start(GTK_BOX(row2), prf->rscl, true, true, 4);
+  sg_box_pack_start(GTK_BOX(row2), prf->rscl, true, true, 4);
 #if (!GTK_CHECK_VERSION(3, 0, 0))
   widget_modify_bg(prf->rscl, GTK_STATE_NORMAL, rscl_color);   /* this is the slider except when clicked */
   widget_modify_bg(prf->rscl, GTK_STATE_PRELIGHT, rscl_color); /* this is the slider when clicked */
@@ -1346,7 +1350,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   prf->gadj = (GtkAdjustment *)gtk_adjustment_new(g, 0.0, 1.01, 0.001, 0.01, .01);
   prf->gscl = gtk_hscale_new(GTK_ADJUSTMENT(prf->gadj));
   gtk_widget_set_name(prf->gscl, "prefs_color_scale");
-  gtk_box_pack_start(GTK_BOX(row2), prf->gscl, true, true, 4);
+  sg_box_pack_start(GTK_BOX(row2), prf->gscl, true, true, 4);
 #if (!GTK_CHECK_VERSION(3, 0, 0))
   widget_modify_bg(prf->gscl, GTK_STATE_NORMAL, gscl_color);
   widget_modify_bg(prf->gscl, GTK_STATE_PRELIGHT, gscl_color);
@@ -1360,7 +1364,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   prf->badj = (GtkAdjustment *)gtk_adjustment_new(b, 0.0, 1.01, 0.001, 0.01, .01);
   prf->bscl = gtk_hscale_new(GTK_ADJUSTMENT(prf->badj));
   gtk_widget_set_name(prf->bscl, "prefs_color_scale");
-  gtk_box_pack_start(GTK_BOX(row2), prf->bscl, true, true, 4);
+  sg_box_pack_start(GTK_BOX(row2), prf->bscl, true, true, 4);
 #if (!GTK_CHECK_VERSION(3, 0, 0))
   widget_modify_bg(prf->bscl, GTK_STATE_NORMAL, bscl_color);
   widget_modify_bg(prf->bscl, GTK_STATE_PRELIGHT, bscl_color);
@@ -1372,7 +1376,7 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
   gtk_scale_set_draw_value(GTK_SCALE(prf->bscl), false);
 
   sep3 = gtk_hseparator_new();
-  gtk_box_pack_end(GTK_BOX(row2), sep3, false, false, 20);
+  sg_box_pack_end(GTK_BOX(row2), sep3, false, false, 20);
   gtk_widget_show(sep3);
 
   SG_SIGNAL_CONNECT(prf->rtxt, "activate", prefs_r_callback, (gpointer)prf);
@@ -1402,7 +1406,7 @@ static void make_inter_topic_separator(GtkWidget *topics)
 {
   GtkWidget *w;
   w = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(topics), w, false, false, 0);
+  sg_box_pack_start(GTK_BOX(topics), w, false, false, 0);
   gtk_widget_show(w);
   /* height = INTER_TOPIC_SPACE no line */
 }
@@ -1414,7 +1418,7 @@ static void make_inter_variable_separator(GtkWidget *topics)
 {
   GtkWidget *w;
   w = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(topics), w, false, false, 0);
+  sg_box_pack_start(GTK_BOX(topics), w, false, false, 0);
   gtk_widget_show(w);
   /* height = INTER_VARIABLE_SPACE no line */
 }
@@ -1428,7 +1432,7 @@ static void make_top_level_label(const char *label, GtkWidget *parent)
   char *str;
 
   w1 = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(parent), w1, false, false, 6);
+  sg_box_pack_start(GTK_BOX(parent), w1, false, false, 6);
   gtk_widget_show(w1);
 
   str = mus_format("<b>%s</b>", label);
@@ -1452,11 +1456,11 @@ static void make_top_level_label(const char *label, GtkWidget *parent)
 
   free(str);
 
-  gtk_box_pack_start(GTK_BOX(parent), w2, false, false, 0);
+  sg_box_pack_start(GTK_BOX(parent), w2, false, false, 0);
   gtk_widget_show(w2);
 
   w3 = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(parent), w3, false, false, 6);
+  sg_box_pack_start(GTK_BOX(parent), w3, false, false, 6);
   gtk_widget_show(w3);
 
   make_inter_variable_separator(parent);
@@ -1468,7 +1472,7 @@ static GtkWidget *make_top_level_box(GtkWidget *topics)
   GtkWidget *w, *frame;
 
   frame = gtk_frame_new(NULL);
-  gtk_box_pack_start(GTK_BOX(topics), frame, true, true, 0);
+  sg_box_pack_start(GTK_BOX(topics), frame, true, true, 0);
   gtk_widget_show(frame);
 
   w = gtk_vbox_new(false, 2);
@@ -1484,7 +1488,7 @@ static void make_inner_label(const char *label, GtkWidget *parent)
   char *str;
 
   w1 = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(parent), w1, false, false, 4);
+  sg_box_pack_start(GTK_BOX(parent), w1, false, false, 4);
   gtk_widget_show(w1);
 
   str = mus_format("<b>%s</b>", label);
@@ -1508,11 +1512,11 @@ static void make_inner_label(const char *label, GtkWidget *parent)
 
   free(str);
 
-  gtk_box_pack_start(GTK_BOX(parent), w, false, false, 0);
+  sg_box_pack_start(GTK_BOX(parent), w, false, false, 0);
   gtk_widget_show(w);
 
   w2 = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(parent), w2, false, false, 4);
+  sg_box_pack_start(GTK_BOX(parent), w2, false, false, 4);
   gtk_widget_show(w2);
 
   make_inter_variable_separator(parent);
@@ -1646,7 +1650,7 @@ widget_t make_preferences_dialog(void)
 #endif
   gtk_window_set_title(GTK_WINDOW(preferences_dialog), "Preferences");
   sg_make_resizable(preferences_dialog);
-  /* gtk_container_set_border_width (GTK_CONTAINER(preferences_dialog), 10); */
+  /* sg_container_set_border_width (GTK_CONTAINER(preferences_dialog), 10); */
   gtk_widget_realize(preferences_dialog);
 
 #if (!GTK_CHECK_VERSION(3, 22, 0))
@@ -1698,7 +1702,7 @@ widget_t make_preferences_dialog(void)
 
   topics = gtk_vbox_new(false, 0);
   scroller = gtk_scrolled_window_new(NULL, NULL);
-  gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(preferences_dialog)), scroller, true, true, 0);
+  sg_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(preferences_dialog)), scroller, true, true, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroller), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 #if HAVE_GTK_HEADER_BAR_NEW
   gtk_container_add(GTK_CONTAINER(scroller), topics);
