@@ -483,14 +483,14 @@ static regrow *make_regrow(GtkWidget *ww, GCallback play_callback, GCallback nam
 
   /* assume "ww" is a vbox widget in this case */
   r->rw = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(ww), r->rw, false, false, 0);
+  sg_box_pack_start(GTK_BOX(ww), r->rw, false, false, 0);
   widget_modify_bg(r->rw, GTK_STATE_NORMAL, ss->white);
   widget_modify_base(r->rw, GTK_STATE_NORMAL, ss->white);
   gtk_widget_show(r->rw);
 
 #if WITH_AUDIO
   r->pl = gtk_check_button_new();
-  gtk_box_pack_start(GTK_BOX(r->rw), r->pl, false, false, 2);
+  sg_box_pack_start(GTK_BOX(r->rw), r->pl, false, false, 2);
   SG_SIGNAL_CONNECT(r->pl, "toggled", play_callback, r);
   gtk_widget_show(r->pl);
 #endif
@@ -498,9 +498,9 @@ static regrow *make_regrow(GtkWidget *ww, GCallback play_callback, GCallback nam
   r->nm = gtk_button_new_with_label("");
   widget_modify_bg(r->nm, GTK_STATE_NORMAL, ss->white);
   widget_modify_base(r->nm, GTK_STATE_NORMAL, ss->white);
-  gtk_button_set_relief(GTK_BUTTON(r->nm), GTK_RELIEF_HALF);
+  gtk_button_set_relief(GTK_BUTTON(r->nm), SG_RELIEF_HALF);
   sg_left_justify_button(r->nm);
-  gtk_box_pack_start(GTK_BOX(r->rw), r->nm, true, true, 2);
+  sg_box_pack_start(GTK_BOX(r->rw), r->nm, true, true, 2);
   add_white_button_style(r->nm);
 
   SG_SIGNAL_CONNECT(r->nm, "clicked", name_callback, r);
@@ -574,7 +574,7 @@ static void make_region_dialog(void)
   SG_SIGNAL_CONNECT(region_dialog, "delete_event", region_browser_delete_callback, NULL);
   gtk_window_set_title(GTK_WINDOW(region_dialog), "Regions");
   sg_make_resizable(region_dialog);
-  gtk_container_set_border_width(GTK_CONTAINER(region_dialog), 10);
+  sg_container_set_border_width(GTK_CONTAINER(region_dialog), 10);
   gtk_window_resize(GTK_WINDOW(region_dialog), 400, 500);
   gtk_widget_realize(region_dialog);
 
@@ -619,7 +619,7 @@ static void make_region_dialog(void)
 
   region_grf = gtk_vpaned_new();
   add_paned_style(region_grf);
-  gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(region_dialog)), region_grf, true, true, 0);
+  sg_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(region_dialog)), region_grf, true, true, 0);
   gtk_widget_show(region_grf);
 
 
@@ -628,15 +628,15 @@ static void make_region_dialog(void)
   gtk_widget_show(toppane);
 
   formw = gtk_vbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(toppane), formw, true, true, 4);
+  sg_box_pack_start(GTK_BOX(toppane), formw, true, true, 4);
   gtk_widget_show(formw);
 
   sep1 = gtk_vseparator_new(); /* not hsep -- damned thing insists on drawing a line */
-  gtk_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
+  sg_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
   gtk_widget_show(sep1);
 
   tophbox = gtk_hbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(formw), tophbox, false, false, 4);
+  sg_box_pack_start(GTK_BOX(formw), tophbox, false, false, 4);
   gtk_widget_show(tophbox);
 
 #if WITH_AUDIO
@@ -646,19 +646,19 @@ static void make_region_dialog(void)
   plw = gtk_button_new_with_label("play"); 
   add_highlight_button_style(plw);
 #endif
-  gtk_box_pack_start(GTK_BOX(tophbox), plw, false, false, 2);
+  sg_box_pack_start(GTK_BOX(tophbox), plw, false, false, 2);
   gtk_widget_show(plw);
 #endif
 
   sep1 = gtk_vseparator_new();
-  gtk_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
+  sg_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
   gtk_widget_show(sep1);
 
 
   region_list = gtk_vbox_new(false, 0);
 
   cww = gtk_scrolled_window_new(NULL, NULL);
-  gtk_box_pack_start(GTK_BOX(formw), cww, true, true, 0);
+  sg_box_pack_start(GTK_BOX(formw), cww, true, true, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(cww), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 #if HAVE_GTK_HEADER_BAR_NEW
   gtk_container_add(GTK_CONTAINER(cww), region_list);
@@ -670,12 +670,12 @@ static void make_region_dialog(void)
   gtk_widget_show(cww);
 
   sep1 = gtk_hseparator_new();
-  gtk_box_pack_end(GTK_BOX(formw), sep1, false, false, 2);
+  sg_box_pack_end(GTK_BOX(formw), sep1, false, false, 2);
   gtk_widget_show(sep1);
 
 
   infobox = gtk_vbox_new(false, 0);
-  gtk_box_pack_start(GTK_BOX(toppane), infobox, false, false, 2);
+  sg_box_pack_start(GTK_BOX(toppane), infobox, false, false, 2);
   gtk_widget_show(infobox);
   
   region_rows = (regrow **)calloc(max_regions(ss), sizeof(regrow *));
@@ -697,7 +697,7 @@ static void make_region_dialog(void)
   /* all I want is an opaque label with a background color */
 
   labels = gtk_event_box_new();
-  gtk_box_pack_start(GTK_BOX(infobox), labels, true, true, 2);
+  sg_box_pack_start(GTK_BOX(infobox), labels, true, true, 2);
   gtk_widget_show(labels);
   widget_modify_bg(labels, GTK_STATE_NORMAL, ss->highlight_color);
   /* SG_SIGNAL_CONNECT(labels, "enter_notify_event", region_labels_mouse_enter, NULL); */
@@ -715,7 +715,7 @@ static void make_region_dialog(void)
   add_highlight_button_style(srate_text);
   sg_left_justify_button(srate_text);
 #endif
-  gtk_box_pack_start(GTK_BOX(labbox), srate_text, false, false, 2);
+  sg_box_pack_start(GTK_BOX(labbox), srate_text, false, false, 2);
   gtk_widget_show(srate_text);
 
 #if (!GTK_CHECK_VERSION(3, 0, 0))
@@ -726,7 +726,7 @@ static void make_region_dialog(void)
   add_highlight_button_style(chans_text);
   sg_left_justify_button(chans_text);
 #endif
-  gtk_box_pack_start(GTK_BOX(labbox), chans_text, false, false, 2);
+  sg_box_pack_start(GTK_BOX(labbox), chans_text, false, false, 2);
   gtk_widget_show(chans_text);
 
 #if (!GTK_CHECK_VERSION(3, 0, 0))
@@ -737,7 +737,7 @@ static void make_region_dialog(void)
   add_highlight_button_style(length_text);
   sg_left_justify_button(length_text);
 #endif
-  gtk_box_pack_start(GTK_BOX(labbox), length_text, false, false, 2);
+  sg_box_pack_start(GTK_BOX(labbox), length_text, false, false, 2);
   gtk_widget_show(length_text);
 
 #if (!GTK_CHECK_VERSION(3, 0, 0))
@@ -748,7 +748,7 @@ static void make_region_dialog(void)
   add_highlight_button_style(maxamp_text);
   sg_left_justify_button(maxamp_text);
 #endif
-  gtk_box_pack_start(GTK_BOX(labbox), maxamp_text, false, false, 2);
+  sg_box_pack_start(GTK_BOX(labbox), maxamp_text, false, false, 2);
   gtk_widget_show(maxamp_text);
 
   gtk_widget_show(region_dialog);
@@ -1065,7 +1065,7 @@ void view_files_callback(GtkWidget *w, gpointer info)
       SG_SIGNAL_CONNECT(view_files_dialog, "delete_event", vf_delete_callback, NULL);
       gtk_window_set_title(GTK_WINDOW(view_files_dialog), "Files");
       sg_make_resizable(view_files_dialog);
-      gtk_container_set_border_width(GTK_CONTAINER(view_files_dialog), 10);
+      sg_container_set_border_width(GTK_CONTAINER(view_files_dialog), 10);
       gtk_window_resize(GTK_WINDOW(view_files_dialog), 300, 500);
       gtk_widget_realize(view_files_dialog);
       
@@ -1087,15 +1087,15 @@ void view_files_callback(GtkWidget *w, gpointer info)
       gtk_widget_show(dismiss_button);
       
       formw = gtk_vbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(view_files_dialog)), formw, true, true, 0);
+      sg_box_pack_start(GTK_BOX(DIALOG_CONTENT_AREA(view_files_dialog)), formw, true, true, 0);
       gtk_widget_show(formw);
       
       sep1 = gtk_vseparator_new(); /* not hsep -- damned thing insists on drawing a line */
-      gtk_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
+      sg_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
       gtk_widget_show(sep1);
       
       tophbox = gtk_hbox_new(false, 0);
-      gtk_box_pack_start(GTK_BOX(formw), tophbox, false, false, 4);
+      sg_box_pack_start(GTK_BOX(formw), tophbox, false, false, 4);
       gtk_widget_show(tophbox);
       
 #if WITH_AUDIO
@@ -1105,18 +1105,18 @@ void view_files_callback(GtkWidget *w, gpointer info)
       plw = gtk_button_new_with_label("play"); 
       add_highlight_button_style(plw);
 #endif
-      gtk_box_pack_start(GTK_BOX(tophbox), plw, false, false, 2);
+      sg_box_pack_start(GTK_BOX(tophbox), plw, false, false, 2);
       gtk_widget_show(plw);
 #endif
       
       sep1 = gtk_vseparator_new();
-      gtk_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
+      sg_box_pack_start(GTK_BOX(formw), sep1, false, false, 2);
       gtk_widget_show(sep1);
       
       vf_list = gtk_vbox_new(false, 0);
       
       cww = gtk_scrolled_window_new(NULL, NULL);
-      gtk_box_pack_start(GTK_BOX(formw), cww, true, true, 0);
+      sg_box_pack_start(GTK_BOX(formw), cww, true, true, 0);
       gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(cww), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 #if HAVE_GTK_HEADER_BAR_NEW
       gtk_container_add(GTK_CONTAINER(cww), vf_list);
