@@ -7,7 +7,7 @@ typedef struct {
   Xen lambda;
   int gc_loc;
   mus_float_t **(*make_rgb)(int size, Xen func);
-  void (*get_rgb)(float x, rgb_t *r, rgb_t *g, rgb_t *b);
+  void (*get_rgb)(double x, rgb_t *r, rgb_t *g, rgb_t *b);
 } cmap;
 
 static cmap **cmaps = NULL;
@@ -98,12 +98,12 @@ void get_current_color(int index, int n, rgb_t *r, rgb_t *g, rgb_t *b)
       cmap *c;
       c = cmaps[index];
       if (c->get_rgb)
-	(c->get_rgb)((float)n / (float)color_map_size(ss), r, g, b);
+	(c->get_rgb)((double)n / (double)color_map_size(ss), r, g, b);
       else
 	{
 	  if (color_map_size(ss) != c->size)
 	    rebuild_colormap(c);
-	  if (n < c->size)
+	  if ((n >= 0) && (n < c->size))
 	    {
 	      (*r) = c->r[n];
 	      (*g) = c->g[n];
@@ -180,7 +180,7 @@ static cmap *new_cmap(const char *name, int size, mus_float_t **rgb)
 
 static cmap *make_builtin_cmap(int size, const char *name, 
 			       mus_float_t **(*make_rgb)(int size, Xen ignored),
-			       void (*get_rgb)(float x, rgb_t *r, rgb_t *g, rgb_t *b))
+			       void (*get_rgb)(double x, rgb_t *r, rgb_t *g, rgb_t *b))
 {
   mus_float_t **rgb = NULL;
   cmap *c = NULL;
@@ -328,7 +328,7 @@ static mus_float_t **make_black_and_white_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void black_and_white_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void black_and_white_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = 0.0;
   (*g) = 0.0;
@@ -360,7 +360,7 @@ static mus_float_t **make_gray_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void gray_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void gray_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = n;
   (*g) = n;
@@ -390,7 +390,7 @@ static mus_float_t **make_autumn_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void autumn_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void autumn_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = 1.0;
   (*g) = n;
@@ -420,7 +420,7 @@ static mus_float_t **make_spring_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void spring_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void spring_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = 1.0;
   (*g) = n;
@@ -450,7 +450,7 @@ static mus_float_t **make_winter_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void winter_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void winter_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = 0.0;
   (*g) = n;
@@ -480,7 +480,7 @@ static mus_float_t **make_summer_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void summer_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void summer_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = n;
   (*g) = 0.5 + (0.5 * n);
@@ -510,7 +510,7 @@ static mus_float_t **make_cool_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void cool_rgb(float n, rgb_t *r, rgb_t *g, rgb_t *b)
+static void cool_rgb(double n, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = n;
   (*g) = 1.0 - n;
@@ -540,7 +540,7 @@ static mus_float_t **make_copper_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void copper_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void copper_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < 0.8) ? (1.25 * x) : 1.0;
   (*g) = 0.8 * x;
@@ -570,7 +570,7 @@ static mus_float_t **make_flag_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void flag_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void flag_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   int k;
   k = ((int)(x * color_map_size(ss))) % 4;
@@ -605,7 +605,7 @@ static mus_float_t **make_prism_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void prism_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void prism_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   int k;
   mus_float_t rs[6] = {1.0, 1.0, 1.0, 0.0, 0.0, 0.6667};
@@ -644,7 +644,7 @@ static mus_float_t **make_bone_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void bone_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void bone_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < .75) ? (x * .875) : ((x * 11.0 / 8.0) - .375);
   (*g) = (x < .375) ? (x * .875) : ((x < .75) ? ((x * 29.0 / 24.0) - .125) : ((x * .875) + .125));
@@ -678,7 +678,7 @@ static mus_float_t **make_hot_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void hot_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void hot_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < .375) ? (x * 8.0 / 3.0) : 1.0;
   (*g) = (x < .375) ? 0.0 : ((x < .75) ? ((x * 8.0 / 3.0) - 1.0) : 1.0);
@@ -712,7 +712,7 @@ static mus_float_t **make_jet_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void jet_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void jet_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < .375) ? 0.0 : ((x < .625) ? ((x * 4.0) - 1.5) : ((x < .875) ? 1.0 : ((x * -4.0) + 4.5)));
   (*g) = (x < .125) ? 0.0 : ((x < .375) ? ((x * 4.0) - 0.5) : ((x < .625) ? 1.0 : ((x < .875) ? ((x * -4.0) + 3.5) : 0.0)));
@@ -746,7 +746,7 @@ static mus_float_t **make_pink_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void pink_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void pink_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < .375) ? (x * 14.0 / 9.0) : ((x * 2.0 / 3.0) + 1.0 / 3.0);
   (*g) = (x < .375) ? (x * 2.0 / 3.0) : ((x < .75) ? ((x * 14.0 / 9.0) - 1.0 / 3.0) : ((x * 2.0 / 3.0) + 1.0 / 3.0));
@@ -780,7 +780,7 @@ static mus_float_t **make_rainbow_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-static void rainbow_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+static void rainbow_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   (*r) = (x < .4) ? 1.0 : ((x < .6) ? ((x * -5.0) + 3.0) : ((x < .8) ? 0.0 : ((x * 10.0 / 3.0) - 8.0 / 3.0)));
   (*g) = (x < .4) ? (x * 2.5) : ((x < .6) ? 1.0 : ((x < .8) ? ((x * -5.0) + 4.0) : 0.0));
@@ -837,7 +837,7 @@ static mus_float_t **make_phases_colormap(int size, Xen ignored)
 
 
 #if USE_GTK
-void phases_rgb(float x, rgb_t *r, rgb_t *g, rgb_t *b)
+void phases_rgb(double x, rgb_t *r, rgb_t *g, rgb_t *b)
 {
   x *= (2.0 * M_PI); /* match code above */
 
@@ -993,6 +993,8 @@ static Xen s7_xen_colormap_length(s7_scheme *sc, Xen obj)
 static Xen g_colormap_ref(Xen map, Xen pos);
 static Xen s7_colormap_apply(s7_scheme *sc, Xen obj, Xen args)
 {
+  if (!s7_is_pair(args))
+    s7_wrong_number_of_args_error(sc, "colormap ref", args);
   return(g_colormap_ref(obj, Xen_car(args)));
 }
 #endif
@@ -1001,8 +1003,12 @@ static Xen s7_colormap_apply(s7_scheme *sc, Xen obj, Xen args)
 static void init_xen_colormap(void)
 {
 #if HAVE_SCHEME
-  xen_colormap_tag = s7_new_type_x(s7, "<colormap>", print_xen_colormap, free_xen_colormap, s7_xen_colormap_equalp, 
-				   NULL, s7_colormap_apply, NULL, s7_xen_colormap_length, NULL, NULL, NULL);
+  xen_colormap_tag = s7_make_c_type(s7, "<colormap>");
+  s7_c_type_set_print(s7, xen_colormap_tag, print_xen_colormap);
+  s7_c_type_set_free(s7, xen_colormap_tag, free_xen_colormap);
+  s7_c_type_set_equal(s7, xen_colormap_tag, s7_xen_colormap_equalp);
+  s7_c_type_set_length(s7, xen_colormap_tag, s7_xen_colormap_length);
+  s7_c_type_set_apply(s7, xen_colormap_tag, s7_colormap_apply);
 #else
 #if HAVE_RUBY
   xen_colormap_tag = Xen_make_object_type("XenColormap", sizeof(xen_colormap));
@@ -1068,7 +1074,7 @@ static Xen g_colormap_ref(Xen map, Xen pos)
 			 map));
 
   x = Xen_real_to_C_double(pos);
-  if ((x < 0.0) || (x > 1.0))
+  if ((isnan(x)) || (x < 0.0) || (x > 1.0))
     Xen_out_of_range_error(S_colormap_ref, 2, pos, "x must be between 0.0 and 1.0");
 
   get_current_color(index, (int)(color_map_size(ss) * x + 0.5), &r, &g, &b);
@@ -1305,8 +1311,8 @@ void g_init_gxcolormaps(void)
 			    s7_make_signature(s7, 1, i),  s7_make_signature(s7, 2, i, i));
 
 #if HAVE_SCHEME
-  s7_symbol_set_access(s7, ss->color_map_size_symbol, s7_make_function(s7, "[acc-" S_colormap_size "]", acc_colormap_size, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->color_map_symbol, s7_make_function(s7, "[acc-" S_colormap "]", acc_colormap, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->color_map_size_symbol, s7_make_function(s7, "[acc-" S_colormap_size "]", acc_colormap_size, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->color_map_symbol, s7_make_function(s7, "[acc-" S_colormap "]", acc_colormap, 2, 0, false, "accessor"));
 
   s7_symbol_set_documentation(s7, ss->color_map_size_symbol, "*colormap-size*: current colormap size; default is 512.");
   s7_symbol_set_documentation(s7, ss->color_map_symbol, "*colormap*: current colormap choice.");
