@@ -673,14 +673,17 @@ snd_data *copy_snd_data(snd_data *sd, mus_long_t beg, int bufsize)
 snd_data *make_snd_data_buffer(mus_float_t *data, int len, int ctr)
 {
   snd_data *sf;
+
   sf = (snd_data *)calloc(1, sizeof(snd_data));
   sf->type = SND_DATA_BUFFER;
   sf->buffered_data = (mus_float_t *)malloc((len + 1) * sizeof(mus_float_t));
-  /* sigh... using len + 1 rather than len to protect against access to inserted buffer at end mixups (final fragment uses end + 1) */
-  /*   the real problem here is that I never decided whether insert starts at the cursor or just past it */
-  /*   when the cursor is on the final sample, this causes cross-fragment ambiguity as to the length of a trailing insertion */
-  /*   C > (make-region 1000 2000) (insert-region (cursor)) C-v hits this empty slot and gets confused about the previously final sample value */
-  memcpy((void *)(sf->buffered_data), (void *)data, len * sizeof(mus_float_t));
+  /* sigh... using len + 1 rather than len to protect against access to inserted buffer at end mixups (final fragment uses end + 1)
+   *   the real problem here is that I never decided whether insert starts at the cursor or just past it
+   *   when the cursor is on the final sample, this causes cross-fragment ambiguity as to the length of a trailing insertion
+   *   C > (make-region 1000 2000) (insert-region (cursor)) C-v hits this empty slot and gets confused about the previously final sample value 
+   */
+
+  mus_copy_floats(sf->buffered_data, data, len);
   sf->buffered_data[len] = 0.0;
   sf->edit_ctr = ctr;
   sf->copy = false;
