@@ -2055,7 +2055,7 @@ Xen new_xen_mark(int n)
   {
     s7_pointer m;
     m = Xen_make_object(xen_mark_tag, mx, 0, free_xen_mark);
-    s7_object_set_let(m, g_mark_methods);
+    s7_c_object_set_let(m, g_mark_methods);
     return(m);
   }
 #else
@@ -2098,11 +2098,13 @@ static s7_pointer mark_to_let_func = NULL;
 static void init_xen_mark(void)
 {
 #if HAVE_SCHEME
-  {
-    g_mark_methods = s7_openlet(s7, s7_inlet(s7, s7_list(s7, 2, s7_make_symbol(s7, "object->let"), mark_to_let_func)));
-    s7_gc_protect(s7, g_mark_methods);
-    xen_mark_tag = s7_new_type_x(s7, "<mark>", print_xen_mark, free_xen_mark, s7_xen_mark_equalp, NULL, NULL, NULL, NULL, s7_xen_mark_copy, NULL, NULL);
-  }
+  g_mark_methods = s7_openlet(s7, s7_inlet(s7, s7_list(s7, 2, s7_make_symbol(s7, "object->let"), mark_to_let_func)));
+  s7_gc_protect(s7, g_mark_methods);
+  xen_mark_tag = s7_make_c_type(s7, "<mark>");
+  s7_c_type_set_print(s7, xen_mark_tag, print_xen_mark);
+  s7_c_type_set_free(s7, xen_mark_tag, free_xen_mark);
+  s7_c_type_set_equal(s7, xen_mark_tag, s7_xen_mark_equalp);
+  s7_c_type_set_copy(s7, xen_mark_tag, s7_xen_mark_copy);
 #else
 #if HAVE_RUBY
   xen_mark_tag = Xen_make_object_type("XenMark", sizeof(xen_mark));
@@ -2718,20 +2720,20 @@ static mark *save_mark(chan_info *cp, mark *m, void *info)
 
 #if HAVE_SCHEME
   if (m->name)
-    fprintf(sv->fd, "(add-mark! %lld sfile %d \"%s\" %s)\n", m->samp, cp->chan, m->name, mapped_sync);
-  else fprintf(sv->fd, "(add-mark! %lld sfile %d #f %s)\n", m->samp, cp->chan, mapped_sync);
+    fprintf(sv->fd, "(add-mark! %" PRId64 " sfile %d \"%s\" %s)\n", m->samp, cp->chan, m->name, mapped_sync);
+  else fprintf(sv->fd, "(add-mark! %" PRId64 " sfile %d #f %s)\n", m->samp, cp->chan, mapped_sync);
 #endif
 
 #if HAVE_RUBY
   if (m->name)
-    fprintf(sv->fd, "add_mark!(%lld, sfile, %d, \"%s\", %s)\n", m->samp, cp->chan, m->name, mapped_sync);
-  else fprintf(sv->fd, "add_mark!(%lld, sfile, %d, false, %s)\n", m->samp, cp->chan, mapped_sync);
+    fprintf(sv->fd, "add_mark!(%" PRId64 ", sfile, %d, \"%s\", %s)\n", m->samp, cp->chan, m->name, mapped_sync);
+  else fprintf(sv->fd, "add_mark!(%" PRId64 ", sfile, %d, false, %s)\n", m->samp, cp->chan, mapped_sync);
 #endif
 
 #if HAVE_FORTH
   if (m->name)
-    fprintf(sv->fd, "%lld sfile %d \"%s\" %s add-mark! drop\n", m->samp, cp->chan, m->name, mapped_sync);
-  else fprintf(sv->fd, "%lld sfile %d #f %s add-mark! drop\n", m->samp, cp->chan, mapped_sync);
+    fprintf(sv->fd, "%" PRId64 " sfile %d \"%s\" %s add-mark! drop\n", m->samp, cp->chan, m->name, mapped_sync);
+  else fprintf(sv->fd, "%" PRId64 " sfile %d #f %s add-mark! drop\n", m->samp, cp->chan, mapped_sync);
 #endif
 
   free(mapped_sync);
@@ -3011,8 +3013,8 @@ If the hook returns " PROC_TRUE ", the mark is not drawn."
   draw_mark_hook = Xen_define_hook(S_draw_mark_hook, "(make-hook 'id)", 1, H_draw_mark_hook);
 
 #if HAVE_SCHEME
-  s7_symbol_set_access(s7, ss->mark_tag_height_symbol, s7_make_function(s7, "[acc-" S_mark_tag_height "]", acc_mark_tag_height, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->mark_tag_width_symbol, s7_make_function(s7, "[acc-" S_mark_tag_width "]", acc_mark_tag_width, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->mark_tag_height_symbol, s7_make_function(s7, "[acc-" S_mark_tag_height "]", acc_mark_tag_height, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->mark_tag_width_symbol, s7_make_function(s7, "[acc-" S_mark_tag_width "]", acc_mark_tag_width, 2, 0, false, "accessor"));
 
   s7_symbol_set_documentation(s7, ss->mark_tag_height_symbol, "*mark-tag-height*: height (pixels) of mark tags (4)");
   s7_symbol_set_documentation(s7, ss->mark_tag_width_symbol, "*mark-tag-width*: width (pixels) of mark tags (10)");
