@@ -252,7 +252,7 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   nchans = hdr->chans;
   if (nchans <= 0) nchans = 1;
 
-  if (nchans > 256)
+  if (nchans > MUS_MAX_CHANS)
     {
       /* either a screwed up header, or Snd was built with wrong endianess */
       /* this kind of error is trapped by raw_data_explanation in make_file_info in the motif/gtk cases */
