@@ -649,13 +649,13 @@ static int paste_region_1(int n, chan_info *cp, bool add, mus_long_t beg, io_err
       else 
 	{
 #if HAVE_FORTH
-	  origin = mus_format("%d %s %lld %s drop", n, S_integer_to_region, beg, S_mix_region);
+	  origin = mus_format("%d %s %" PRId64 " %s drop", n, S_integer_to_region, beg, S_mix_region);
 #endif
 #if HAVE_RUBY
-	  origin = mus_format("%s(%s(%d), %lld", to_proc_name(S_mix_region), to_proc_name(S_integer_to_region), n, beg);
+	  origin = mus_format("%s(%s(%d), %" PRId64, to_proc_name(S_mix_region), to_proc_name(S_integer_to_region), n, beg);
 #endif
 #if HAVE_SCHEME || (!HAVE_EXTENSION_LANGUAGE)
-	  origin = mus_format("%s (%s %d) %lld", S_mix_region, S_integer_to_region, n, beg);
+	  origin = mus_format("%s (%s %d) %" PRId64, S_mix_region, S_integer_to_region, n, beg);
 #endif
 	  if (si->chans > 1)
 	    remember_temp(newname, si->chans);
@@ -687,13 +687,13 @@ static int paste_region_1(int n, chan_info *cp, bool add, mus_long_t beg, io_err
 	}
 
 #if HAVE_FORTH
-	  origin = mus_format("%d %s %lld %s drop", n, S_integer_to_region, beg, S_insert_region);
+	  origin = mus_format("%d %s %" PRId64 " %s drop", n, S_integer_to_region, beg, S_insert_region);
 #endif
 #if HAVE_RUBY
-	  origin = mus_format("%s(%s(%d), %lld", to_proc_name(S_insert_region), to_proc_name(S_integer_to_region), n, beg);
+	  origin = mus_format("%s(%s(%d), %" PRId64, to_proc_name(S_insert_region), to_proc_name(S_integer_to_region), n, beg);
 #endif
 #if HAVE_SCHEME || (!HAVE_EXTENSION_LANGUAGE)
-	  origin = mus_format("%s (%s %d) %lld", S_insert_region, S_integer_to_region, n, beg);
+	  origin = mus_format("%s (%s %d) %" PRId64, S_insert_region, S_integer_to_region, n, beg);
 #endif
 
       for (i = 0; ((i < r->chans) && (i < si->chans)); i++)
@@ -1127,25 +1127,25 @@ void save_regions(FILE *fd)
 	  else
 	    {
 #if HAVE_RUBY
-	      fprintf(fd, "%s(%d, %d, %lld, %d, %.4f, \"%s\", \"%s\", \"%s\", ",
+	      fprintf(fd, "%s(%d, %d, %" PRId64 ", %d, %.4f, \"%s\", \"%s\", \"%s\", ",
 		      "restore_region", i, r->chans, r->framples, r->srate, r->maxamp, r->name, r->start, r->end);
-	      fprintf(fd, " \"%s\", [%d, %lld])\n",
+	      fprintf(fd, " \"%s\", [%d, %" PRId64 "])\n",
 		      newname,
 		      (int)mus_sound_write_date(newname),
 		      mus_sound_length(newname));
 #endif
 #if HAVE_SCHEME
-	      fprintf(fd, "(%s %d %d %lld %d %.4f \"%s\" \"%s\" \"%s\"",
+	      fprintf(fd, "(%s %d %d %" PRId64 " %d %.4f \"%s\" \"%s\" \"%s\"",
 		      S_restore_region, i, r->chans, r->framples, r->srate, r->maxamp, r->name, r->start, r->end);
-	      fprintf(fd, " \"%s\" (list %d %lld))\n",
+	      fprintf(fd, " \"%s\" (list %d %" PRId64 "))\n",
 		      newname,
 		      (int)mus_sound_write_date(newname),
 		      mus_sound_length(newname));
 #endif
 #if HAVE_FORTH
-	  fprintf(fd, "%d %d %lld %d %.4f \"%s\" \"%s\" \"%s\"",
+	  fprintf(fd, "%d %d %" PRId64 " %d %.4f \"%s\" \"%s\" \"%s\"",
 	          i, r->chans, r->framples, r->srate, r->maxamp, r->name, r->start, r->end);
- 	  fprintf(fd, " \"%s\" '( %d %lld ) %s drop\n",
+ 	  fprintf(fd, " \"%s\" '( %d %" PRId64 " ) %s drop\n",
  		  newname,
  		  (int)mus_sound_write_date(newname),
  		  mus_sound_length(newname),
@@ -1331,7 +1331,7 @@ io_error_t save_region(int rg, const char *name, mus_sample_t samp_type, mus_hea
 	      for (i = 0; i < chans; i++) bufs[i] = (mus_float_t *)calloc(FILE_BUFFER_SIZE, sizeof(mus_float_t));
 
 	      if (((framples * chans * mus_sound_datum_size(r->filename)) >> 10) > disk_kspace(name))
-		snd_warning("not enough space to save region? -- need %lld bytes",
+		snd_warning("not enough space to save region? -- need %" PRId64 " bytes",
 			    framples * chans * mus_sound_datum_size(r->filename));
 
 	      for (ioff = 0; ioff < framples; ioff += FILE_BUFFER_SIZE)
@@ -1493,7 +1493,11 @@ static Xen s7_xen_region_length(s7_scheme *sc, Xen obj)
 static void init_xen_region(void)
 {
 #if HAVE_SCHEME
-  xen_region_tag = s7_new_type_x(s7, "<region>", print_xen_region, free_xen_region, s7_xen_region_equalp, NULL, NULL, NULL, s7_xen_region_length, NULL, NULL, NULL);
+  xen_region_tag = s7_make_c_type(s7, "<region>");
+  s7_c_type_set_print(s7, xen_region_tag, print_xen_region);
+  s7_c_type_set_free(s7, xen_region_tag, free_xen_region);
+  s7_c_type_set_equal(s7, xen_region_tag, s7_xen_region_equalp);
+  s7_c_type_set_length(s7, xen_region_tag, s7_xen_region_length);
 #else
 #if HAVE_RUBY
   xen_region_tag = Xen_make_object_type("XenRegion", sizeof(xen_region));
@@ -1559,6 +1563,7 @@ static Xen g_restore_region(Xen args)
   int i, regn;
   Xen arg, pos, chans, len, srate, maxamp, name, start, end, filename, date;
   
+  Xen_check_type(Xen_list_length(args) == 10, args, 0, S_restore_region, "10 items");
   arg = args;
   pos = Xen_car(arg);
   Xen_check_type(Xen_is_integer(pos), pos, 1, S_restore_region, "a region id");
@@ -2322,8 +2327,8 @@ void g_init_regions(void)
 			    s7_make_signature(s7, 1, i), s7_make_signature(s7, 2, i, i));
 
 #if HAVE_SCHEME
-  s7_symbol_set_access(s7, ss->max_regions_symbol, s7_make_function(s7, "[acc-" S_max_regions "]", acc_max_regions, 2, 0, false, "accessor"));
-  s7_symbol_set_access(s7, ss->region_graph_style_symbol, s7_make_function(s7, "[acc-" S_region_graph_style "]", acc_region_graph_style, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->max_regions_symbol, s7_make_function(s7, "[acc-" S_max_regions "]", acc_max_regions, 2, 0, false, "accessor"));
+  s7_symbol_set_setter(s7, ss->region_graph_style_symbol, s7_make_function(s7, "[acc-" S_region_graph_style "]", acc_region_graph_style, 2, 0, false, "accessor"));
 
   s7_symbol_set_documentation(s7, ss->max_regions_symbol, "*max-regions*: max number of regions saved on the region list");
   s7_symbol_set_documentation(s7, ss->region_graph_style_symbol, "*region-graph-style*: graph style of the region dialog graph (graph-lines etc)");
