@@ -379,13 +379,13 @@ static int mix_selection(chan_info *cp, sync_info *si_out, mus_long_t beg, io_er
     {
       char *origin = NULL;
 #if HAVE_FORTH
-      origin = mus_format("%lld snd chn %s", beg, S_mix_selection);
+      origin = mus_format("%" PRId64 " snd chn %s", beg, S_mix_selection);
 #else
   #if HAVE_SCHEME
-      origin = mus_format("-mix-selection- %lld %lld %lld snd chn",
+      origin = mus_format("-mix-selection- %" PRId64 " %" PRId64 " %" PRId64 " snd chn",
                           beg, selection_beg(cp), selection_len());
   #else
-      origin = mus_format("%s" PROC_OPEN "%lld", to_proc_name(S_mix_selection), beg);
+      origin = mus_format("%s" PROC_OPEN "%" PRId64, to_proc_name(S_mix_selection), beg);
   #endif
 #endif
       if (si_out->chans > 1)
@@ -461,9 +461,9 @@ static io_error_t insert_selection(chan_info *cp, sync_info *si_out, mus_long_t
 	      cp_in = si_in->cps[i];   /* selection chan to paste in (no wrap-around here) */
 	      len = cp_selection_len(cp_in, NULL);
 #if HAVE_FORTH
-	      origin = mus_format("%lld %s", beg, S_insert_selection);
+	      origin = mus_format("%" PRId64 " %s", beg, S_insert_selection);
 #else
-	      origin = mus_format("%s" PROC_OPEN "%lld", to_proc_name(S_insert_selection), beg);
+	      origin = mus_format("%s" PROC_OPEN "%" PRId64, to_proc_name(S_insert_selection), beg);
 #endif
 	      if (file_insert_samples(beg, len,
 				      tempfile, cp_out, i,
@@ -1038,10 +1038,13 @@ static Xen s7_xen_selection_fill(s7_scheme *sc, Xen args)
 static void init_xen_selection(void)
 {
 #if HAVE_SCHEME
-  xen_selection_tag = s7_new_type_x(s7, "<selection>", 
-				    print_xen_selection, free_xen_selection, s7_xen_selection_equalp, 
-				    NULL, NULL, NULL, s7_xen_selection_length, 
-				    s7_xen_selection_copy, NULL, s7_xen_selection_fill);
+  xen_selection_tag = s7_make_c_type(s7, "<selection>");
+  s7_c_type_set_print(s7, xen_selection_tag, print_xen_selection);
+  s7_c_type_set_free(s7, xen_selection_tag, free_xen_selection);
+  s7_c_type_set_equal(s7, xen_selection_tag, s7_xen_selection_equalp);
+  s7_c_type_set_length(s7, xen_selection_tag, s7_xen_selection_length);
+  s7_c_type_set_copy(s7, xen_selection_tag, s7_xen_selection_copy);
+  s7_c_type_set_fill(s7, xen_selection_tag, s7_xen_selection_fill);
 #else
 #if HAVE_RUBY
   xen_selection_tag = Xen_make_object_type("XenSelection", sizeof(xen_selection));
