@@ -591,12 +591,12 @@
 #define S_src_channel                   "src-channel"
 #define S_src_selection                 "src-selection"
 #define S_src_sound                     "src-sound"
-#define S_start_hook                    "start-hook"
 #define S_start_playing                 "start-playing"
 #define S_start_playing_hook            "start-playing-hook"
 #define S_start_playing_selection_hook  "start-playing-selection-hook"
 #define S_start_progress_report         "start-progress-report"
 #define S_status_report                 "status-report"
+#define S_stdin_prompt                  "stdin-prompt"
 #define S_stop_player                   "stop-player"
 #define S_stop_playing                  "stop-playing"
 #define S_stop_playing_hook             "stop-playing-hook"
