@@ -41,7 +41,7 @@ static int64_t snd_checked_write(int fd, unsigned char *buf, int64_t bytes, cons
   if (kfree < (bytes >> 10))
     { 
       snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   "only %lld bytes left on device (we need %" PRId64 " bytes)",
+		   "only %" PRId64 " bytes left on device (we need %" PRId64 " bytes)",
 		   kfree << 10, bytes);
       return(MUS_ERROR);
     }
@@ -141,7 +141,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
   STARTUP(oldname, newname, TRANS_BUF_SIZE, unsigned char);
   totalin = read(fd, buf, TRANS_BUF_SIZE);
   bits = buf[6];
-  srate = (int)(1.0e9 / (float)((buf[7] + (buf[8] << 7) + (buf[9] << 14))));
+  srate = (int)(1.0e9 / (double)((buf[7] + (buf[8] << 7) + (buf[9] << 14))));
   samples = (buf[10] + (buf[11] << 7) + (buf[12] << 14));
   mus_bint_to_char((unsigned char *)(hdr + 16), srate);
   mus_bint_to_char((unsigned char *)(hdr + 20), chans);
@@ -397,7 +397,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   ssize_t totalin;
   bool happy;
   int osp;
-  float fsrate, fraction;
+  double fsrate, fraction;
   int srateH, srateL, sign, exponent, chans, mode;
   STARTUP(oldname, newname, PDP_BUF_SIZE, unsigned char);
   totalin = read(fd, buf, PDP_BUF_SIZE);      
