@@ -491,7 +491,7 @@ static void display_sound_file_entry(FILE *fp, const char *name, sound_file *sf)
     strftime(timestr, TIME_BUFFER_SIZE, "%a %d-%b-%Y %H:%M:%S", localtime(&date));
   else snprintf(timestr, TIME_BUFFER_SIZE, "(date cleared)");
 
-  fprintf(fp, "  %s: %s, chans: %d, srate: %d, header: %s, data: %s, samps: %lld",
+  fprintf(fp, "  %s: %s, chans: %d, srate: %d, header: %s, data: %s, samps: %" PRId64,
 	  name,
 	  timestr,
 	  sf->chans,
@@ -524,7 +524,7 @@ static void display_sound_file_entry(FILE *fp, const char *name, sound_file *sf)
 	      if (i > 1) fprintf(fp, ", ");
 	      fprintf(fp, " %.3f at %.3f ",
 		      sf->maxamps[i],
-		      (sf->srate > 0) ? (float)((double)(sf->maxtimes[i]) / (double)(sf->srate)) : (float)(sf->maxtimes[i]));
+		      (sf->srate > 0) ? ((double)(sf->maxtimes[i]) / (double)(sf->srate)) : (double)(sf->maxtimes[i]));
 	    }
 	}
     }
@@ -821,7 +821,7 @@ float mus_sound_duration(const char *arg)
   if (sf) 
     {
       if ((sf->chans > 0) && (sf->srate > 0))
-	val = (float)((double)(sf->samples) / ((float)(sf->chans) * (float)(sf->srate)));
+	val = ((double)(sf->samples) / ((double)(sf->chans) * (double)(sf->srate)));
       else val = 0.0;
     }
   return(val);
@@ -1305,7 +1305,7 @@ int mus_sound_set_maxamps(const char *ifile, int chans, mus_float_t *vals, mus_l
   sound_file *sf; 
   int result = MUS_NO_ERROR;
 
-  /* fprintf(stderr, "set %s maxamps: %d %.3f %lld\n", ifile, chans, vals[0], times[0]); */
+  /* fprintf(stderr, "set %s maxamps: %d %.3f %" PRId64 "\n", ifile, chans, vals[0], times[0]); */
   sf = get_sf(ifile); 
   if (sf)
     {
@@ -1382,7 +1382,7 @@ mus_float_t mus_sound_channel_maxamp(const char *file, int chan, mus_long_t *pos
 void mus_sound_channel_set_maxamp(const char *file, int chan, mus_float_t mx, mus_long_t pos)
 {
   sound_file *sf; 
-  /* fprintf(stderr, "set %s maxamp: %.3f %lld\n", file, mx, pos); */
+  /* fprintf(stderr, "set %s maxamp: %.3f %" PRId64 "\n", file, mx, pos); */
   sf = get_sf(file); 
   if ((sf) &&
       (sf->chans > chan))
