@@ -36,7 +36,11 @@
        (let ((info (ow 'error-data)))
 	 (if (and (pair? info)
 		  (string? (car info)))
-	     (format p ": ~A" (apply format #f info))
+	     (format p ": ~A" (catch #t 
+				(lambda () 
+				  (apply format #f info))
+				(lambda args 
+				  "<error in format>")))
 	     (if (not (null? info))
 		 (format p ": ~A" info))))
 
@@ -93,6 +97,22 @@
 	      (format *stderr* "~%~A~%" (stacktrace)))))
 |#
 
+;;; ----------------
+(define-macro (typed-let vals . body) ; vals: ((var init [type])...)...) as in (typed-let ((i 0 integer?))...)
+  `(let ,(map (lambda (val)
+		 (list (car val) (cadr val)))
+	       vals)
+     ,@(map (lambda (val)
+	      (if (pair? (cddr val))
+		  `(set! (symbol-setter ',(car val)) 
+			 (lambda (s v)
+			   (if (not (,(caddr val) v))
+			       (error 'wrong-type-arg "(set! ~S ~S) but ~S is not ~A" s v v ',(caddr val)))
+			   v))
+		  (values)))
+	    vals)
+     ,@body))
+
 
 ;;; ----------------
 (define (first obj)  (if (sequence? obj) (obj 0) (error 'wrong-type-arg "first argument, ~S, is not a sequence" obj)))
@@ -120,12 +140,7 @@
 	    ((null? p) lst)
 	  (set! (car p) i))))))
 
-(define (cdr* lst n)
-  (do ((i n (- i 1))
-       (result lst (cdr result))) 
-      ((or (null? result)
-	   (zero? i)) 
-       result)))
+;(define cdr* list-tail)
 
 (define make-circular-list 
   (let ((+documentation+ "(make-circular-list n init) returns a circular list with n entries initialized to init:\n\
@@ -1669,7 +1684,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		   #f))
 
           ((not end) 
-	   (cdr* obj start))
+	   (list-tail obj start))
 
           (else
            (do ((lst (make-list new-len #f))
@@ -2058,6 +2073,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :cpu-time                      (*s7* 'cpu-time)
    :heap-size                     (*s7* 'heap-size)
    :free-heap-size                (*s7* 'free-heap-size)
+   :max-heap-size                 (*s7* 'max-heap-size)
    :gc-freed                      (*s7* 'gc-freed)
    :gc-protected-objects          (*s7* 'gc-protected-objects)
    :gc-stats                      (*s7* 'gc-stats)
@@ -2162,6 +2178,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		    (sublet lt)))))))
 
 ;;; (sandbox '(let ((x 1)) (+ x 2))) -> 3
+;;; (sandbox '(let ((x 1)) (+ x 2) (exit))) -> #f
 
 (define sandbox 
   (let ((+documentation+ "(sandbox code) evaluates code in an environment where nothing outside that code can be affected by its evaluation.")
@@ -2206,7 +2223,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	      call-with-exit apply for-each map dynamic-wind values type-of
 	      catch throw error documentation signature help procedure-source
 	      setter arity aritable? not eq? eqv? equal? morally-equal? s7-version
-	      dilambda make-hook hook-functions stacktrace tree-leaves tree-memq object->let
+	      dilambda make-hook hook-functions stacktrace tree-leaves tree-memq tree-set-memq tree-cyclic? tree-count object->let
 	      pi most-positive-fixnum most-negative-fixnum nan.0 inf.0 -nan.0 -inf.0
 	      *stderr* *stdout* *stdin*
 	      apply-values list-values
