@@ -27,11 +27,18 @@
     (or (string? (iterate iter))
 	(and (not (iterator-at-end? iter))
 	     (loop)))))
-    
+
 (define-constant (find-if-d iter)
   (do ()
       ((or (string? (iterate iter)) (iterator-at-end? iter))
        (not (iterator-at-end? iter)))))
+#|
+;;; exactly the same speed:
+(define-constant (find-if-d iter)
+  (do ((x (iterate iter) (iterate iter)))
+      ((or (string? x) (iterator-at-end? iter))
+       (string? x))))
+|#
 
 (define (test)
   (for-each
@@ -52,7 +59,7 @@
 		      (find-if-b (make-iterator vc))
 		      (find-if-c (make-iterator vc))
 		      (find-if-d (make-iterator vc)))))
-	   (d (let ((fv (make-float-vector size 0.0)))
+	   (d (let ((fv (make-float-vector size 1.0)))
 		(list (find-if-a (make-iterator fv))
 		      (find-if-b (make-iterator fv))
 		      (find-if-c (make-iterator fv))
@@ -99,3 +106,4 @@
 
 (s7-version)	
 (exit)
+
