@@ -1,14 +1,14 @@
 ;;; sequence tests
 
 (define (less-than a b)
-  (or (< a b) #f))
+  (or (< a b) (> b a)))
 
 (define (less-than-2 a b)
   (if (not (real? a)) (display "oops"))
   (cond ((< a b) #t) (#t #f)))
 
 (define (char-less-than a b) 
-  (cond ((char<? a b) #t) (#t #f)))
+  (cond ((char<? a b) #t) (else #f)))
 
 
 (define (fv-tst len)
@@ -194,7 +194,7 @@
 	  ((null? p))
 	(set-car! p (- (random 100000) 50000)))
       (let ((fv-ran (copy fv)))
-	(sort! fv <)
+	(set! fv (sort! fv <))
 	(call-with-exit
 	 (lambda (quit)
 	   (do ((p0 fv (cdr p0))
@@ -204,7 +204,7 @@
 	     (when (> (car p0) (car p1))
 	       (format *stderr* "list: ~A > ~A at ~D~%" (car p0) (car p1) i)
 	       (quit)))))
-	(sort! fv-ran (lambda (a b) (< a b)))
+	(set! fv-ran (sort! fv-ran (lambda (a b) (< a b))))
 	(if (not (equal? fv fv-ran))
 	    (format *stderr* "pair closure not equal~%")))
 	
@@ -247,7 +247,6 @@
       (if (not (= (ht i) i)) (display "oops")))))
 
 
-
 (define (test-it)
   (for-each
    (lambda (b p)
@@ -311,9 +310,74 @@
   (fe13 size)
   (fe13 1))
 
+
+;;; this is a revision of some code posted in comp.lang.lisp by melzzzzz for euler project 512
+;;;   apparently sbcl computes the big case (below) in "about a minute" -- well, so does s7!
+;;;   53 secs sbcl, 80 in s7
+
+(define (make-boolean-vector n)
+  (make-int-vector (ceiling (/ n 63))))
+
+(define-expansion (boolean-vector-ref v n)
+  `(logbit? (int-vector-ref ,v (quotient ,n 63)) (remainder ,n 63)))
+
+(define-expansion (boolean-vector-set! v n)
+  `(int-vector-set! ,v (quotient ,n 63)
+		    (logior (int-vector-ref ,v (quotient ,n 63))
+			    (ash 1 (remainder ,n 63)))))
+
+(define (odd-get n)
+  (let* ((visited-range (+ (ash n -1) 1))
+	 (visited (make-boolean-vector visited-range))
+	 (sqrt-n (+ (floor (sqrt n)) 1)))
+    (do ((i 3 (+ i 2)))
+	((>= i sqrt-n))
+      (unless (boolean-vector-ref visited (ash i -1))
+	(do ((j (ash (* i i) -1) (+ j i)))
+	    ((>= j visited-range))
+	  (boolean-vector-set! visited j))))
+    (let ((rc (make-int-vector (+ n 1) 0))
+	  (rcp 0)
+	  (lim (+ n 1)))
+      (do ((i 3 (+ i 2)))
+	  ((= i lim) (copy rc (make-int-vector rcp)))
+	(unless (boolean-vector-ref visited (ash i -1))
+	  (int-vector-set! rc rcp i)
+	  (set! rcp (+ rcp 1)))))))
+
+(define (getr n)
+  (let* ((odd-bound (ash (+ n 1) -1))
+	 (prime-list (odd-get n))
+	 (result (make-int-vector odd-bound 0))
+	 (resp 0)
+	 (n2 (/ n 2))) ; this optimization suggested by "Peter" (in comp.lang.lisp)
+    (do ((i 0 (+ i 1)))
+	((= i odd-bound))
+      (int-vector-set! result i (+ (* 2 i) 1)))
+
+    (for-each (lambda (prime)
+		(do ((j (ash prime -1) (+ j prime)))
+		    ((>= j n2))
+		  (int-vector-set! result j (* (quotient (int-vector-ref result j) prime) (- prime 1)))))
+	      prime-list)
+
+   (let ((sum 0))
+      (do ((i 0 (+ i 1)))
+	  ((= i odd-bound) sum)
+	(set! sum (+ sum (int-vector-ref result i)))))))
+
+(let ((r (getr 100)))
+  (unless (= r 2007)
+    (display r)
+    (newline)))
+
+(let ((r (getr 500000)))
+  (unless (= r 50660660193)
+    (display r)
+    (newline)))
+
+;;; (display (getr 500000000)) ;50660591862310323
+
 (s7-version)
 (exit)
 
-
-
-;;; unsafe, strings, precheck types in vect cases
\ No newline at end of file
