@@ -10,11 +10,13 @@
  */
 
 #define XEN_MAJOR_VERSION 3
-#define XEN_MINOR_VERSION 26
-#define XEN_VERSION "3.26"
+#define XEN_MINOR_VERSION 27
+#define XEN_VERSION "3.27"
 
 /* HISTORY:
  *
+ *  2-Aug-17:  changed XEN_MAKE_OBJECT_TYPE in s7.
+ *  --------
  *  29-Jul-16: Xen_define_unsafe_typed_procedure.
  *  --------
  *  20-Aug-15: Xen_define_typed_procedure, Xen_define_typed_dilambda.
@@ -313,7 +315,7 @@
 #define XEN_NAME_AS_C_STRING_TO_VALUE(a) xen_rb_gv_get(a)
 #define XEN_EVAL_C_STRING(Arg)          xen_rb_eval_string_with_error(Arg)
 #define XEN_TO_STRING(Obj)              xen_rb_obj_as_string(Obj)
-#define XEN_LOAD_FILE(a)                xen_rb_load_file_with_error(C_TO_XEN_STRING(a))
+#define XEN_LOAD_FILE(a)                xen_rb_load_file_with_error(a)
 #define XEN_LOAD_PATH                   XEN_NAME_AS_C_STRING_TO_VALUE("$LOAD_PATH")
 #define XEN_ADD_TO_LOAD_PATH(Path)      xen_rb_add_to_load_path(Path)
 
@@ -450,7 +452,7 @@
 /* ---- keywords, etc ---- */
 #define XEN_KEYWORD_EQ_P(k1, k2)        ((k1) == (k2))
 #define XEN_MAKE_KEYWORD(Arg)           xen_rb_make_keyword(Arg)
-#define XEN_PROVIDE(a)                  rb_provide(a)
+#define XEN_PROVIDE(a)                  rb_provide(xen_strdup(a))
 #define XEN_PROTECT_FROM_GC(Var)        rb_gc_register_address(&(Var))
 #define XEN_UNPROTECT_FROM_GC(Var)      rb_gc_unregister_address(&(Var))
 
@@ -647,7 +649,7 @@ XEN xen_rb_list_set(XEN obj, int index, XEN value);
 void xen_rb_raise(XEN type, XEN info);
 XEN xen_rb_obj_as_string(XEN obj);
 XEN xen_rb_eval_string_with_error(const char *str);
-XEN xen_rb_load_file_with_error(XEN file);
+void xen_rb_load_file_with_error(const char *file);
 XEN xen_rb_ary_new_with_initial_element(long num, XEN element);
 XEN xen_rb_apply(XEN func, XEN args);
 XEN xen_rb_funcall_0(XEN func);
@@ -1066,7 +1068,7 @@ extern size_t xen_s7_number_location, xen_s7_denominator_location;
 
 #define XEN_ULONG_LONG_P(Arg)                      s7_is_ulong_long(Arg) 
 #define XEN_TO_C_ULONG_LONG(Arg)                   s7_ulong_long(Arg) 
-#define C_TO_XEN_ULONG_LONG(Arg)                   s7_make_ulong_long(s7, (unsigned long long)Arg) 
+#define C_TO_XEN_ULONG_LONG(Arg)                   s7_make_ulong_long(s7, (uint64_t)Arg) 
 
 #define C_TO_XEN_LONG_LONG(Arg)                    s7_make_integer(s7, Arg)
 #define XEN_TO_C_LONG_LONG(Arg)                    s7_integer(Arg)
@@ -1203,16 +1205,29 @@ typedef XEN (*XEN_CATCH_BODY_TYPE)                                    (void *dat
 
 #define XEN_MARK_OBJECT_TYPE                                          void
 #define XEN_MAKE_OBJECT_TYPE(Name, Print, Free, Equal, Gc_Mark, Apply, Set, Length, Copy, Reverse, Fill) \
-                                                                      s7_new_type_x(Name, Print, Free, Equal, Gc_Mark, Apply, Set, Length, Copy, Reverse, Fill)
+  ({ int32_t tag;							\
+     tag = s7_make_c_type(s7, Name);					\
+     if (Print) s7_c_type_set_print(s7, tag, Print);			\
+     if (Free) s7_c_type_set_free(s7, tag, Free);			\
+     if (Equal) s7_c_type_set_equal(s7, tag, Equal);			\
+     if (Gc_Mark) s7_c_type_set_mark(s7, tag, Gc_Mark);			\
+     if (Apply) s7_c_type_set_apply(s7, tag, Apply);			\
+     if (Set) s7_c_type_set_set(s7, tag, Set);				\
+     if (Length) s7_c_type_set_length(s7, tag, Length);			\
+     if (Copy) s7_c_type_set_copy(s7, tag, Copy);			\
+     if (Reverse) s7_c_type_set_reverse(s7, tag, Reverse);		\
+     if (Fill) s7_c_type_set_fill(s7, tag, Fill);			\
+  tag; })
+
 #define XEN_MAKE_OBJECT_FREE_PROCEDURE(Type, Wrapped_Free, Original_Free) \
                                                                       static void Wrapped_Free(void *obj) {Original_Free((Type *)obj);}
 #define XEN_MAKE_OBJECT_PRINT_PROCEDURE(Type, Wrapped_Print, Original_Print) \
                                                                       static char *Wrapped_Print(s7_scheme *sc, void *obj) {return(Original_Print((Type *)obj));}
-#define XEN_MAKE_AND_RETURN_OBJECT(Tag, Val, ig1, ig2)                return(s7_make_object(s7, Tag, Val))
-#define XEN_MAKE_OBJECT(Tag, Val, ig1, ig2)                           s7_make_object(s7, Tag, Val)
-#define XEN_OBJECT_REF(Arg)                                           s7_object_value(Arg)
+#define XEN_MAKE_AND_RETURN_OBJECT(Tag, Val, ig1, ig2)                return(s7_make_c_object(s7, Tag, Val))
+#define XEN_MAKE_OBJECT(Tag, Val, ig1, ig2)                           s7_make_c_object(s7, Tag, Val)
+#define XEN_OBJECT_REF(Arg)                                           s7_c_object_value(Arg)
 #define XEN_OBJECT_TYPE                                               int /* tag type */
-#define XEN_OBJECT_TYPE_P(Obj, Tag)                                   (s7_object_type(Obj) == Tag)
+#define XEN_OBJECT_TYPE_P(Obj, Tag)                                   (s7_c_object_type(Obj) == Tag)
 
 #define XEN_HOOK_P(Arg)                                               ((Arg) != XEN_FALSE)
 #define XEN_DEFINE_HOOK(Name, Descr, Arity, Help)                     s7_define_constant_with_documentation(s7, Name, s7_eval_c_string(s7, Descr), Help)
@@ -1495,10 +1510,10 @@ void xen_no_ext_lang_check_args(const char *name, int args, int req_args, int op
   #define XEN_UNWRAP_C_POINTER(a)         s7_c_pointer(a)
 #else
   #if (SIZEOF_VOID_P == 4) 
-    #define XEN_WRAP_C_POINTER(a)         ((XEN)(C_TO_XEN_ULONG((unsigned int)a))) 
+    #define XEN_WRAP_C_POINTER(a)         ((XEN)(C_TO_XEN_ULONG((unsigned long)a))) 
     #define XEN_UNWRAP_C_POINTER(a)       XEN_TO_C_ULONG(a) 
   #else 
-    #define XEN_WRAP_C_POINTER(a)         C_TO_XEN_ULONG_LONG((unsigned long long int)(a)) 
+    #define XEN_WRAP_C_POINTER(a)         C_TO_XEN_ULONG_LONG((uint64_t)(a)) 
     #define XEN_UNWRAP_C_POINTER(a)       XEN_TO_C_ULONG_LONG(a) 
   #endif
 #endif
